:root[data-theme-mode=dark] {
    --ColorNeutral1: #111111;
    --ColorNeutral2: #191919;
    --ColorNeutral3: #222222;
    --ColorNeutral4: #2a2a2a;
    --ColorNeutral5: #313131;
    --ColorNeutral6: #3a3a3a;
    --ColorNeutral7: #484848;
    --ColorNeutral8: #606060;
    --ColorNeutral9: #6e6e6e;
    --ColorNeutral10: #7b7b7b;
    --ColorNeutral11: #b4b4b4;
    --ColorNeutral12: #eeeeee;
    --ColorNeutralAlpha1: #00000000;
    --ColorNeutralAlpha2: #ffffff09;
    --ColorNeutralAlpha3: #ffffff12;
    --ColorNeutralAlpha4: #ffffff1b;
    --ColorNeutralAlpha5: #ffffff22;
    --ColorNeutralAlpha6: #ffffff2c;
    --ColorNeutralAlpha7: #ffffff3b;
    --ColorNeutralAlpha8: #ffffff55;
    --ColorNeutralAlpha9: #ffffff64;
    --ColorNeutralAlpha10: #ffffff72;
    --ColorNeutralAlpha11: #ffffffaf;
    --ColorNeutralAlpha12: #ffffffed;
    --ColorYellow1: #14120b;
    --ColorYellow2: #1b180f;
    --ColorYellow3: #2d2305;
    --ColorYellow4: #362b00;
    --ColorYellow5: #433500;
    --ColorYellow6: #524202;
    --ColorYellow7: #665417;
    --ColorYellow8: #836a21;
    --ColorYellow9: #ffe629;
    --ColorYellow10: #ffff57;
    --ColorYellow11: #f5e147;
    --ColorYellow12: #f6eeb4;
    --ColorRed1: #191111;
    --ColorRed2: #201314;
    --ColorRed3: #3b1219;
    --ColorRed4: #500f1c;
    --ColorRed5: #611623;
    --ColorRed6: #72232d;
    --ColorRed7: #8c333a;
    --ColorRed8: #b54548;
    --ColorRed9: #e5484d;
    --ColorRed10: #ec5d5e;
    --ColorRed11: #ff9592;
    --ColorRed12: #ffd1d9;
    --ColorOrange1: #17120e;
    --ColorOrange2: #1e160f;
    --ColorOrange3: #331e0b;
    --ColorOrange4: #462100;
    --ColorOrange5: #562800;
    --ColorOrange6: #66350c;
    --ColorOrange7: #7e451d;
    --ColorOrange8: #a35829;
    --ColorOrange9: #f76b15;
    --ColorOrange10: #ff801f;
    --ColorOrange11: #ffa057;
    --ColorOrange12: #ffe0c2;
    --ColorBlue1: #0d1520;
    --ColorBlue2: #111927;
    --ColorBlue3: #0d2847;
    --ColorBlue4: #003362;
    --ColorBlue5: #004074;
    --ColorBlue6: #104d87;
    --ColorBlue7: #205d9e;
    --ColorBlue8: #2870bd;
    --ColorBlue9: #0090ff;
    --ColorBlue10: #3b9eff;
    --ColorBlue11: #70b8ff;
    --ColorBlue12: #c2e6ff;
    --ColorGreen1: #0e1512;
    --ColorGreen2: #121b17;
    --ColorGreen3: #132d21;
    --ColorGreen4: #113b29;
    --ColorGreen5: #174933;
    --ColorGreen6: #20573e;
    --ColorGreen7: #28684a;
    --ColorGreen8: #2f7c57;
    --ColorGreen9: #30a46c;
    --ColorGreen10: #33b074;
    --ColorGreen11: #3dd68c;
    --ColorGreen12: #b1f1cb;
    --ColorPurple1: #18111b;
    --ColorPurple2: #1e1523;
    --ColorPurple3: #301c3b;
    --ColorPurple4: #3d224e;
    --ColorPurple5: #48295c;
    --ColorPurple6: #54346b;
    --ColorPurple7: #664282;
    --ColorPurple8: #8457aa;
    --ColorPurple9: #8e4ec6;
    --ColorPurple10: #9a5cd0;
    --ColorPurple11: #d19dff;
    --ColorPurple12: #ecd9fa;
    --FontsBody: Inter, -apple-system, BlinkMacSystemFont, avenir next, avenir, helvetica neue, helvetica, Ubuntu, roboto, noto, segoe ui, arial, sans-serif;
    --FontsMono: Consolas, "Andale Mono WT", "Andale Mono", "Lucida Console", "Lucida Sans Typewriter", "DejaVu Sans Mono", "Bitstream Vera Sans Mono", "Liberation Mono", "Nimbus Mono L", Monaco, "Courier New", Courier, monospace;
    --Space2: 2px;
    --Space4: 4px;
    --Space8: 8px;
    --Space12: 12px;
    --Space16: 16px;
    --Space20: 20px;
    --Space24: 24px;
    --Space28: 28px;
    --SpaceNone: 0;
    --SpaceAuto: auto;
    --SpaceFull: 100%;
    --SpaceFit: fit-content;
    --SpaceMax: max-content;
    --SpaceMin: min-content
}

* {
    box-sizing: border-box
}

body {
    font-family: var(--FontsBody)
}

:root {
    --hairline-border-width: 1px
}

@media (min-resolution: 2x) {
    :root {
        --hairline-border-width: .5px
    }
}

@media (min-resolution: 3x) {
    :root {
        --hairline-border-width: calc(1px / 3)
    }
}

:root[data-theme-mode=light] {
    --ColorNeutral1: #fcfcfc;
    --ColorNeutral2: #f9f9f9;
    --ColorNeutral3: #f0f0f0;
    --ColorNeutral4: #e8e8e8;
    --ColorNeutral5: #e0e0e0;
    --ColorNeutral6: #d9d9d9;
    --ColorNeutral7: #cecece;
    --ColorNeutral8: #bbbbbb;
    --ColorNeutral9: #8d8d8d;
    --ColorNeutral10: #838383;
    --ColorNeutral11: #646464;
    --ColorNeutral12: #202020;
    --ColorNeutralAlpha1: #00000003;
    --ColorNeutralAlpha2: #00000006;
    --ColorNeutralAlpha3: #0000000f;
    --ColorNeutralAlpha4: #00000017;
    --ColorNeutralAlpha5: #0000001f;
    --ColorNeutralAlpha6: #00000026;
    --ColorNeutralAlpha7: #00000031;
    --ColorNeutralAlpha8: #00000044;
    --ColorNeutralAlpha9: #00000072;
    --ColorNeutralAlpha10: #0000007c;
    --ColorNeutralAlpha11: #0000009b;
    --ColorNeutralAlpha12: #000000df;
    --ColorYellow1: #fdfdf9;
    --ColorYellow2: #fefce9;
    --ColorYellow3: #fffab8;
    --ColorYellow4: #fff394;
    --ColorYellow5: #ffe770;
    --ColorYellow6: #f3d768;
    --ColorYellow7: #e4c767;
    --ColorYellow8: #d5ae39;
    --ColorYellow9: #ffe629;
    --ColorYellow10: #ffdc00;
    --ColorYellow11: #9e6c00;
    --ColorYellow12: #473b1f;
    --ColorRed1: #fffcfc;
    --ColorRed2: #fff7f7;
    --ColorRed3: #feebec;
    --ColorRed4: #ffdbdc;
    --ColorRed5: #ffcdce;
    --ColorRed6: #fdbdbe;
    --ColorRed7: #f4a9aa;
    --ColorRed8: #eb8e90;
    --ColorRed9: #e5484d;
    --ColorRed10: #dc3e42;
    --ColorRed11: #ce2c31;
    --ColorRed12: #641723;
    --ColorOrange1: #fefcfb;
    --ColorOrange2: #fff7ed;
    --ColorOrange3: #ffefd6;
    --ColorOrange4: #ffdfb5;
    --ColorOrange5: #ffd19a;
    --ColorOrange6: #ffc182;
    --ColorOrange7: #f5ae73;
    --ColorOrange8: #ec9455;
    --ColorOrange9: #f76b15;
    --ColorOrange10: #ef5f00;
    --ColorOrange11: #cc4e00;
    --ColorOrange12: #582d1d;
    --ColorBlue1: #fbfdff;
    --ColorBlue2: #f4faff;
    --ColorBlue3: #e6f4fe;
    --ColorBlue4: #d5efff;
    --ColorBlue5: #c2e5ff;
    --ColorBlue6: #acd8fc;
    --ColorBlue7: #8ec8f6;
    --ColorBlue8: #5eb1ef;
    --ColorBlue9: #0090ff;
    --ColorBlue10: #0588f0;
    --ColorBlue11: #0d74ce;
    --ColorBlue12: #113264;
    --ColorGreen1: #fbfefc;
    --ColorGreen2: #f4fbf6;
    --ColorGreen3: #e6f6eb;
    --ColorGreen4: #d6f1df;
    --ColorGreen5: #c4e8d1;
    --ColorGreen6: #adddc0;
    --ColorGreen7: #8eceaa;
    --ColorGreen8: #5bb98b;
    --ColorGreen9: #30a46c;
    --ColorGreen10: #2b9a66;
    --ColorGreen11: #218358;
    --ColorGreen12: #193b2d;
    --ColorPurple1: #fefcfe;
    --ColorPurple2: #fbf7fe;
    --ColorPurple3: #f7edfe;
    --ColorPurple4: #f2e2fc;
    --ColorPurple5: #ead5f9;
    --ColorPurple6: #e0c4f4;
    --ColorPurple7: #d1afec;
    --ColorPurple8: #be93e4;
    --ColorPurple9: #8e4ec6;
    --ColorPurple10: #8347b9;
    --ColorPurple11: #8145b5;
    --ColorPurple12: #402060;
    --FontsBody: Inter, -apple-system, BlinkMacSystemFont, avenir next, avenir, helvetica neue, helvetica, Ubuntu, roboto, noto, segoe ui, arial, sans-serif;
    --FontsMono: Consolas, "Andale Mono WT", "Andale Mono", "Lucida Console", "Lucida Sans Typewriter", "DejaVu Sans Mono", "Bitstream Vera Sans Mono", "Liberation Mono", "Nimbus Mono L", Monaco, "Courier New", Courier, monospace;
    --Space2: 2px;
    --Space4: 4px;
    --Space8: 8px;
    --Space12: 12px;
    --Space16: 16px;
    --Space20: 20px;
    --Space24: 24px;
    --Space28: 28px;
    --SpaceNone: 0;
    --SpaceAuto: auto;
    --SpaceFull: 100%;
    --SpaceFit: fit-content;
    --SpaceMax: max-content;
    --SpaceMin: min-content
}

._1hdtoq89 {
    box-shadow: inset var(--hairline-border-width) 0 0 var(--ColorNeutral4), inset 0 var(--hairline-border-width) 0 var(--ColorNeutral4), inset calc(-1 * var(--hairline-border-width)) 0 0 var(--ColorNeutral4), inset 0 calc(-1 * var(--hairline-border-width)) 0 0 var(--ColorNeutral4)
}

._1hdtoq8a {
    box-shadow: inset var(--hairline-border-width) 0 0 var(--ColorNeutral4)
}

._1hdtoq8b {
    box-shadow: inset 0 var(--hairline-border-width) 0 var(--ColorNeutral4)
}

._1hdtoq8c {
    box-shadow: inset calc(-1 * var(--hairline-border-width)) 0 0 var(--ColorNeutral4)
}

._1hdtoq8d {
    box-shadow: inset 0 calc(-1 * var(--hairline-border-width)) 0 0 var(--ColorNeutral4)
}

._1hdtoq8e {
    box-shadow: inset var(--hairline-border-width) 0 0 var(--ColorNeutral6), inset 0 var(--hairline-border-width) 0 var(--ColorNeutral6), inset calc(-1 * var(--hairline-border-width)) 0 0 var(--ColorNeutral6), inset 0 calc(-1 * var(--hairline-border-width)) 0 0 var(--ColorNeutral6)
}

._1hdtoq8f {
    box-shadow: inset var(--hairline-border-width) 0 0 var(--ColorNeutral6)
}

._1hdtoq8g {
    box-shadow: inset 0 var(--hairline-border-width) 0 var(--ColorNeutral6)
}

._1hdtoq8h {
    box-shadow: inset calc(-1 * var(--hairline-border-width)) 0 0 var(--ColorNeutral6)
}

._1hdtoq8i {
    box-shadow: inset 0 calc(-1 * var(--hairline-border-width)) 0 0 var(--ColorNeutral6)
}

._1hdtoq8j {
    box-shadow: inset var(--hairline-border-width) 0 0 var(--ColorNeutral7), inset 0 var(--hairline-border-width) 0 var(--ColorNeutral7), inset calc(-1 * var(--hairline-border-width)) 0 0 var(--ColorNeutral7), inset 0 calc(-1 * var(--hairline-border-width)) 0 0 var(--ColorNeutral7)
}

._1hdtoq8k {
    box-shadow: inset var(--hairline-border-width) 0 0 var(--ColorNeutral7)
}

._1hdtoq8l {
    box-shadow: inset 0 var(--hairline-border-width) 0 var(--ColorNeutral7)
}

._1hdtoq8m {
    box-shadow: inset calc(-1 * var(--hairline-border-width)) 0 0 var(--ColorNeutral7)
}

._1hdtoq8n {
    box-shadow: inset 0 calc(-1 * var(--hairline-border-width)) 0 0 var(--ColorNeutral7)
}

.qn82t90 {
    all: unset;
    cursor: pointer;
    box-sizing: border-box;
    border: none;
    background-color: transparent;
    margin: 0;
    padding: 0
}

._1tfioa10 {
    scrollbar-width: thin;
    scrollbar-color: var(--ColorNeutral7) transparent
}

._1tfioa10::-webkit-scrollbar {
    width: 2px;
    height: 2px
}

._1tfioa10::-webkit-scrollbar-track {
    background: transparent
}

._1tfioa10::-webkit-scrollbar-thumb {
    background-color: var(--ColorNeutral7);
    border-radius: 4px
}

.monaco-editor {
    font-family: -apple-system, BlinkMacSystemFont, Segoe WPC, Segoe UI, HelveticaNeue-Light, system-ui, Ubuntu, Droid Sans, sans-serif;
    --monaco-monospace-font: "SF Mono", Monaco, Menlo, Consolas, "Ubuntu Mono", "Liberation Mono", "DejaVu Sans Mono", "Courier New", monospace
}

.monaco-menu .monaco-action-bar.vertical .action-item .action-menu-item:focus .action-label {
    stroke-width: 1.2px
}

.monaco-editor.vs-dark .monaco-menu .monaco-action-bar.vertical .action-menu-item:focus .action-label,
.monaco-editor.hc-black .monaco-menu .monaco-action-bar.vertical .action-menu-item:focus .action-label,
.monaco-editor.hc-light .monaco-menu .monaco-action-bar.vertical .action-menu-item:focus .action-label {
    stroke-width: 1.2px
}

.monaco-hover p {
    margin: 0
}

.monaco-aria-container {
    position: absolute !important;
    top: 0;
    height: 1px;
    width: 1px;
    margin: -1px;
    overflow: hidden;
    padding: 0;
    clip: rect(1px, 1px, 1px, 1px);
    clip-path: inset(50%)
}

.monaco-aria-container {
    position: absolute;
    left: -999em
}

::-ms-clear {
    display: none
}

.monaco-editor .editor-widget input {
    color: inherit
}

.monaco-editor {
    position: relative;
    overflow: visible;
    -webkit-text-size-adjust: 100%;
    color: var(--vscode-editor-foreground);
    background-color: var(--vscode-editor-background)
}

.monaco-editor-background {
    background-color: var(--vscode-editor-background)
}

.monaco-editor .rangeHighlight {
    background-color: var(--vscode-editor-rangeHighlightBackground);
    box-sizing: border-box;
    border: 1px solid var(--vscode-editor-rangeHighlightBorder)
}

.monaco-editor.hc-black .rangeHighlight,
.monaco-editor.hc-light .rangeHighlight {
    border-style: dotted
}

.monaco-editor .symbolHighlight {
    background-color: var(--vscode-editor-symbolHighlightBackground);
    box-sizing: border-box;
    border: 1px solid var(--vscode-editor-symbolHighlightBorder)
}

.monaco-editor.hc-black .symbolHighlight,
.monaco-editor.hc-light .symbolHighlight {
    border-style: dotted
}

.monaco-editor .overflow-guard {
    position: relative;
    overflow: hidden
}

.monaco-editor .view-overlays {
    position: absolute;
    top: 0
}

.monaco-editor .squiggly-error {
    border-bottom: 4px double var(--vscode-editorError-border)
}

.monaco-editor .squiggly-error:before {
    display: block;
    content: "";
    width: 100%;
    height: 100%;
    background: var(--vscode-editorError-background)
}

.monaco-editor .squiggly-warning {
    border-bottom: 4px double var(--vscode-editorWarning-border)
}

.monaco-editor .squiggly-warning:before {
    display: block;
    content: "";
    width: 100%;
    height: 100%;
    background: var(--vscode-editorWarning-background)
}

.monaco-editor .squiggly-info {
    border-bottom: 4px double var(--vscode-editorInfo-border)
}

.monaco-editor .squiggly-info:before {
    display: block;
    content: "";
    width: 100%;
    height: 100%;
    background: var(--vscode-editorInfo-background)
}

.monaco-editor .squiggly-hint {
    border-bottom: 2px dotted var(--vscode-editorHint-border)
}

.monaco-editor.showUnused .squiggly-unnecessary {
    border-bottom: 2px dashed var(--vscode-editorUnnecessaryCode-border)
}

.monaco-editor.showDeprecated .squiggly-inline-deprecated {
    text-decoration: line-through;
    text-decoration-color: var(--vscode-editor-foreground, inherit)
}

.monaco-scrollable-element>.scrollbar>.scra {
    cursor: pointer;
    font-size: 11px !important
}

.monaco-scrollable-element>.visible {
    opacity: 1;
    background: rgba(0, 0, 0, 0);
    transition: opacity .1s linear;
    z-index: 11
}

.monaco-scrollable-element>.invisible {
    opacity: 0;
    pointer-events: none
}

.monaco-scrollable-element>.invisible.fade {
    transition: opacity .8s linear
}

.monaco-scrollable-element>.shadow {
    position: absolute;
    display: none
}

.monaco-scrollable-element>.shadow.top {
    display: block;
    top: 0;
    left: 3px;
    height: 3px;
    width: 100%;
    box-shadow: var(--vscode-scrollbar-shadow) 0 6px 6px -6px inset
}

.monaco-scrollable-element>.shadow.left {
    display: block;
    top: 3px;
    left: 0;
    height: 100%;
    width: 3px;
    box-shadow: var(--vscode-scrollbar-shadow) 6px 0 6px -6px inset
}

.monaco-scrollable-element>.shadow.top-left-corner {
    display: block;
    top: 0;
    left: 0;
    height: 3px;
    width: 3px
}

.monaco-scrollable-element>.shadow.top.left {
    box-shadow: var(--vscode-scrollbar-shadow) 6px 0 6px -6px inset
}

.monaco-scrollable-element>.scrollbar>.slider {
    background: var(--vscode-scrollbarSlider-background)
}

.monaco-scrollable-element>.scrollbar>.slider:hover {
    background: var(--vscode-scrollbarSlider-hoverBackground)
}

.monaco-scrollable-element>.scrollbar>.slider.active {
    background: var(--vscode-scrollbarSlider-activeBackground)
}

.monaco-editor .inputarea {
    min-width: 0;
    min-height: 0;
    margin: 0;
    padding: 0;
    position: absolute;
    outline: none !important;
    resize: none;
    border: none;
    overflow: hidden;
    color: transparent;
    background-color: transparent;
    z-index: -10
}

.monaco-editor .inputarea.ime-input {
    z-index: 10;
    caret-color: var(--vscode-editorCursor-foreground);
    color: var(--vscode-editor-foreground)
}

.monaco-editor .margin-view-overlays .line-numbers {
    font-variant-numeric: tabular-nums;
    position: absolute;
    text-align: right;
    display: inline-block;
    vertical-align: middle;
    box-sizing: border-box;
    cursor: default;
    height: 100%
}

.monaco-editor .relative-current-line-number {
    text-align: left;
    display: inline-block;
    width: 100%
}

.monaco-editor .margin-view-overlays .line-numbers.lh-odd {
    margin-top: 1px
}

.monaco-editor .line-numbers {
    color: var(--vscode-editorLineNumber-foreground)
}

.monaco-editor .line-numbers.active-line-number {
    color: var(--vscode-editorLineNumber-activeForeground)
}

.monaco-editor .margin {
    background-color: var(--vscode-editorGutter-background)
}

.monaco-mouse-cursor-text {
    cursor: text
}

.monaco-editor .view-overlays .current-line,
.monaco-editor .margin-view-overlays .current-line {
    display: block;
    position: absolute;
    left: 0;
    top: 0;
    box-sizing: border-box
}

.monaco-editor .margin-view-overlays .current-line.current-line-margin.current-line-margin-both {
    border-right: 0
}

.monaco-editor .lines-content .cdr {
    position: absolute
}

.monaco-editor .lines-content .core-guide {
    position: absolute;
    box-sizing: border-box
}

.monaco-editor .lines-content .core-guide-indent {
    box-shadow: 1px 0 0 0 var(--vscode-editorIndentGuide-background) inset
}

.monaco-editor .lines-content .core-guide-indent-active {
    box-shadow: 1px 0 0 0 var(--vscode-editorIndentGuide-activeBackground, --vscode-editorIndentGuide-background) inset
}

.mtkcontrol {
    color: #fff !important;
    background: rgb(150, 0, 0) !important
}

.mtkoverflow {
    background-color: var(--vscode-button-background, --vscode-editor-background);
    color: var(--vscode-button-foreground, --vscode-editor-foreground);
    border-width: 1px;
    border-style: solid;
    border-color: var(--vscode-contrastBorder);
    border-radius: 2px;
    padding: 4px;
    cursor: pointer
}

.mtkoverflow:hover {
    background-color: var(--vscode-button-hoverBackground)
}

.monaco-editor.no-user-select .lines-content,
.monaco-editor.no-user-select .view-line,
.monaco-editor.no-user-select .view-lines {
    user-select: none;
    -webkit-user-select: none
}

.monaco-editor.mac .lines-content:hover,
.monaco-editor.mac .view-line:hover,
.monaco-editor.mac .view-lines:hover {
    user-select: text;
    -webkit-user-select: text;
    -ms-user-select: text
}

.monaco-editor.enable-user-select {
    user-select: initial;
    -webkit-user-select: initial
}

.monaco-editor .view-lines {
    white-space: nowrap
}

.monaco-editor .view-line {
    position: absolute;
    width: 100%
}

.monaco-editor .mtkw {
    color: var(--vscode-editorWhitespace-foreground) !important
}

.monaco-editor .mtkz {
    display: inline-block;
    color: var(--vscode-editorWhitespace-foreground) !important
}

.monaco-editor .lines-decorations {
    position: absolute;
    top: 0;
    background: white
}

.monaco-editor .margin-view-overlays .cldr {
    position: absolute;
    height: 100%
}

.monaco-editor .glyph-margin {
    position: absolute;
    top: 0
}

.monaco-editor .glyph-margin-widgets .cgmr {
    position: absolute;
    display: flex;
    align-items: center
}

.monaco-editor .margin-view-overlays .cmdr {
    position: absolute;
    left: 0;
    width: 100%;
    height: 100%
}

.monaco-editor .minimap.slider-mouseover .minimap-slider {
    opacity: 0;
    transition: opacity .1s linear
}

.monaco-editor .minimap.slider-mouseover:hover .minimap-slider,
.monaco-editor .minimap.slider-mouseover .minimap-slider.active {
    opacity: 1
}

.monaco-editor .minimap-slider .minimap-slider-horizontal {
    background: var(--vscode-minimapSlider-background)
}

.monaco-editor .minimap-slider:hover .minimap-slider-horizontal {
    background: var(--vscode-minimapSlider-hoverBackground)
}

.monaco-editor .minimap-slider.active .minimap-slider-horizontal {
    background: var(--vscode-minimapSlider-activeBackground)
}

.monaco-editor .minimap-shadow-visible {
    box-shadow: var(--vscode-scrollbar-shadow) -6px 0 6px -6px inset
}

.monaco-editor .minimap-shadow-hidden {
    position: absolute;
    width: 0
}

.monaco-editor .minimap-shadow-visible {
    position: absolute;
    left: -6px;
    width: 6px
}

.monaco-editor.no-minimap-shadow .minimap-shadow-visible {
    position: absolute;
    left: -1px;
    width: 1px
}

.minimap.autohide {
    opacity: 0;
    transition: opacity .5s
}

.minimap.autohide:hover {
    opacity: 1
}

.monaco-editor .overlayWidgets {
    position: absolute;
    top: 0;
    left: 0
}

.monaco-editor .view-ruler {
    position: absolute;
    top: 0;
    box-shadow: 1px 0 0 0 var(--vscode-editorRuler-foreground) inset
}

.monaco-editor .scroll-decoration {
    position: absolute;
    top: 0;
    left: 0;
    height: 6px;
    box-shadow: var(--vscode-scrollbar-shadow) 0 6px 6px -6px inset
}

.monaco-editor .lines-content .cslr {
    position: absolute
}

.monaco-editor .focused .selected-text {
    background-color: var(--vscode-editor-selectionBackground)
}

.monaco-editor .selected-text {
    background-color: var(--vscode-editor-inactiveSelectionBackground)
}

.monaco-editor .top-left-radius {
    border-top-left-radius: 3px
}

.monaco-editor .bottom-left-radius {
    border-bottom-left-radius: 3px
}

.monaco-editor .top-right-radius {
    border-top-right-radius: 3px
}

.monaco-editor .bottom-right-radius {
    border-bottom-right-radius: 3px
}

.monaco-editor.hc-black .top-left-radius {
    border-top-left-radius: 0
}

.monaco-editor.hc-black .bottom-left-radius {
    border-bottom-left-radius: 0
}

.monaco-editor.hc-black .top-right-radius {
    border-top-right-radius: 0
}

.monaco-editor.hc-black .bottom-right-radius {
    border-bottom-right-radius: 0
}

.monaco-editor.hc-light .top-left-radius {
    border-top-left-radius: 0
}

.monaco-editor.hc-light .bottom-left-radius {
    border-bottom-left-radius: 0
}

.monaco-editor.hc-light .top-right-radius {
    border-top-right-radius: 0
}

.monaco-editor.hc-light .bottom-right-radius {
    border-bottom-right-radius: 0
}

.monaco-editor .cursors-layer {
    position: absolute;
    top: 0
}

.monaco-editor .cursors-layer>.cursor {
    position: absolute;
    overflow: hidden;
    box-sizing: border-box
}

.monaco-editor .cursors-layer.cursor-smooth-caret-animation>.cursor {
    transition: all 80ms
}

.monaco-editor .cursors-layer.cursor-block-outline-style>.cursor {
    background: transparent !important;
    border-style: solid;
    border-width: 1px
}

.monaco-editor .cursors-layer.cursor-underline-style>.cursor {
    border-bottom-width: 2px;
    border-bottom-style: solid;
    background: transparent !important
}

.monaco-editor .cursors-layer.cursor-underline-thin-style>.cursor {
    border-bottom-width: 1px;
    border-bottom-style: solid;
    background: transparent !important
}

@keyframes monaco-cursor-smooth {

    0%,
    20% {
        opacity: 1
    }

    60%,
    to {
        opacity: 0
    }
}

@keyframes monaco-cursor-phase {

    0%,
    20% {
        opacity: 1
    }

    90%,
    to {
        opacity: 0
    }
}

@keyframes monaco-cursor-expand {

    0%,
    20% {
        transform: scaleY(1)
    }

    80%,
    to {
        transform: scaleY(0)
    }
}

.cursor-smooth {
    animation: monaco-cursor-smooth .5s ease-in-out 0s 20 alternate
}

.cursor-phase {
    animation: monaco-cursor-phase .5s ease-in-out 0s 20 alternate
}

.cursor-expand>.cursor {
    animation: monaco-cursor-expand .5s ease-in-out 0s 20 alternate
}

.monaco-editor .blockDecorations-container {
    position: absolute;
    top: 0;
    pointer-events: none
}

.monaco-editor .blockDecorations-block {
    position: absolute;
    box-sizing: border-box
}

.monaco-editor .mwh {
    position: absolute;
    color: var(--vscode-editorWhitespace-foreground) !important
}

:root {
    --vscode-sash-size: 4px
}

.monaco-sash {
    position: absolute;
    z-index: 35;
    touch-action: none
}

.monaco-sash.disabled {
    pointer-events: none
}

.monaco-sash.mac.vertical {
    cursor: col-resize
}

.monaco-sash.vertical.minimum {
    cursor: e-resize
}

.monaco-sash.vertical.maximum {
    cursor: w-resize
}

.monaco-sash.mac.horizontal {
    cursor: row-resize
}

.monaco-sash.horizontal.minimum {
    cursor: s-resize
}

.monaco-sash.horizontal.maximum {
    cursor: n-resize
}

.monaco-sash.disabled {
    cursor: default !important;
    pointer-events: none !important
}

.monaco-sash.vertical {
    cursor: ew-resize;
    top: 0;
    width: var(--vscode-sash-size);
    height: 100%
}

.monaco-sash.horizontal {
    cursor: ns-resize;
    left: 0;
    width: 100%;
    height: var(--vscode-sash-size)
}

.monaco-sash:not(.disabled)>.orthogonal-drag-handle {
    content: " ";
    height: calc(var(--vscode-sash-size) * 2);
    width: calc(var(--vscode-sash-size) * 2);
    z-index: 100;
    display: block;
    cursor: all-scroll;
    position: absolute
}

.monaco-sash.horizontal.orthogonal-edge-north:not(.disabled)>.orthogonal-drag-handle.start,
.monaco-sash.horizontal.orthogonal-edge-south:not(.disabled)>.orthogonal-drag-handle.end {
    cursor: nwse-resize
}

.monaco-sash.horizontal.orthogonal-edge-north:not(.disabled)>.orthogonal-drag-handle.end,
.monaco-sash.horizontal.orthogonal-edge-south:not(.disabled)>.orthogonal-drag-handle.start {
    cursor: nesw-resize
}

.monaco-sash.vertical>.orthogonal-drag-handle.start {
    left: calc(var(--vscode-sash-size) * -.5);
    top: calc(var(--vscode-sash-size) * -1)
}

.monaco-sash.vertical>.orthogonal-drag-handle.end {
    left: calc(var(--vscode-sash-size) * -.5);
    bottom: calc(var(--vscode-sash-size) * -1)
}

.monaco-sash.horizontal>.orthogonal-drag-handle.start {
    top: calc(var(--vscode-sash-size) * -.5);
    left: calc(var(--vscode-sash-size) * -1)
}

.monaco-sash.horizontal>.orthogonal-drag-handle.end {
    top: calc(var(--vscode-sash-size) * -.5);
    right: calc(var(--vscode-sash-size) * -1)
}

.monaco-sash:before {
    content: "";
    pointer-events: none;
    position: absolute;
    width: 100%;
    height: 100%;
    background: transparent
}

.monaco-workbench:not(.reduce-motion) .monaco-sash:before {
    transition: background-color .1s ease-out
}

.monaco-sash.hover:before,
.monaco-sash.active:before {
    background: var(--vscode-sash-hoverBorder)
}

.monaco-sash.vertical:before {
    width: var(--vscode-sash-hover-size);
    left: calc(50% - (var(--vscode-sash-hover-size) / 2))
}

.monaco-sash.horizontal:before {
    height: var(--vscode-sash-hover-size);
    top: calc(50% - (var(--vscode-sash-hover-size) / 2))
}

.pointer-events-disabled {
    pointer-events: none !important
}

.monaco-sash.debug {
    background: cyan
}

.monaco-sash.debug.disabled {
    background: rgba(0, 255, 255, .2)
}

.monaco-sash.debug:not(.disabled)>.orthogonal-drag-handle {
    background: red
}

.monaco-diff-editor .diffOverview {
    z-index: 9
}

.monaco-diff-editor .diffOverview .diffViewport {
    z-index: 10
}

.monaco-diff-editor.vs .diffOverview {
    background: rgba(0, 0, 0, .03)
}

.monaco-diff-editor.vs-dark .diffOverview {
    background: rgba(255, 255, 255, .01)
}

.monaco-scrollable-element.modified-in-monaco-diff-editor.vs .scrollbar,
.monaco-scrollable-element.modified-in-monaco-diff-editor.vs-dark .scrollbar {
    background: rgba(0, 0, 0, 0)
}

.monaco-scrollable-element.modified-in-monaco-diff-editor.hc-black .scrollbar,
.monaco-scrollable-element.modified-in-monaco-diff-editor.hc-light .scrollbar {
    background: none
}

.monaco-scrollable-element.modified-in-monaco-diff-editor .slider {
    z-index: 10
}

.modified-in-monaco-diff-editor .slider.active {
    background: rgba(171, 171, 171, .4)
}

.modified-in-monaco-diff-editor.hc-black .slider.active,
.modified-in-monaco-diff-editor.hc-light .slider.active {
    background: none
}

.monaco-editor .insert-sign,
.monaco-diff-editor .insert-sign,
.monaco-editor .delete-sign,
.monaco-diff-editor .delete-sign {
    font-size: 11px !important;
    opacity: .7 !important;
    display: flex !important;
    align-items: center
}

.monaco-editor.hc-black .insert-sign,
.monaco-diff-editor.hc-black .insert-sign,
.monaco-editor.hc-black .delete-sign,
.monaco-diff-editor.hc-black .delete-sign,
.monaco-editor.hc-light .insert-sign,
.monaco-diff-editor.hc-light .insert-sign,
.monaco-editor.hc-light .delete-sign,
.monaco-diff-editor.hc-light .delete-sign {
    opacity: 1
}

.monaco-editor .inline-deleted-margin-view-zone,
.monaco-editor .inline-added-margin-view-zone {
    text-align: right
}

.monaco-editor .arrow-revert-change {
    z-index: 10;
    position: absolute
}

.monaco-editor .arrow-revert-change:hover {
    cursor: pointer
}

.monaco-editor .view-zones .view-lines .view-line span {
    display: inline-block
}

.monaco-editor .margin-view-zones .lightbulb-glyph:hover {
    cursor: pointer
}

.monaco-editor .char-insert,
.monaco-diff-editor .char-insert {
    background-color: var(--vscode-diffEditor-insertedTextBackground)
}

.monaco-editor .line-insert,
.monaco-diff-editor .line-insert {
    background-color: var(--vscode-diffEditor-insertedLineBackground, --vscode-diffEditor-insertedTextBackground)
}

.monaco-editor .line-insert,
.monaco-editor .char-insert {
    box-sizing: border-box;
    border: 1px solid var(--vscode-diffEditor-insertedTextBorder)
}

.monaco-editor.hc-black .line-insert,
.monaco-editor.hc-light .line-insert,
.monaco-editor.hc-black .char-insert,
.monaco-editor.hc-light .char-insert {
    border-style: dashed
}

.monaco-editor .line-delete,
.monaco-editor .char-delete {
    box-sizing: border-box;
    border: 1px solid var(--vscode-diffEditor-removedTextBorder)
}

.monaco-editor.hc-black .line-delete,
.monaco-editor.hc-light .line-delete,
.monaco-editor.hc-black .char-delete,
.monaco-editor.hc-light .char-delete {
    border-style: dashed
}

.monaco-editor .inline-added-margin-view-zone,
.monaco-editor .gutter-insert,
.monaco-diff-editor .gutter-insert {
    background-color: var(--vscode-diffEditorGutter-insertedLineBackground, --vscode-diffEditor-insertedLineBackground, --vscode-diffEditor-insertedTextBackground)
}

.monaco-editor .char-delete,
.monaco-diff-editor .char-delete {
    background-color: var(--vscode-diffEditor-removedTextBackground)
}

.monaco-editor .line-delete,
.monaco-diff-editor .line-delete {
    background-color: var(--vscode-diffEditor-removedLineBackground, --vscode-diffEditor-removedTextBackground)
}

.monaco-editor .inline-deleted-margin-view-zone,
.monaco-editor .gutter-delete,
.monaco-diff-editor .gutter-delete {
    background-color: var(--vscode-diffEditorGutter-removedLineBackground, --vscode-diffEditor-removedLineBackground, --vscode-diffEditor-removedTextBackground)
}

.monaco-diff-editor.side-by-side .editor.modified {
    box-shadow: -6px 0 5px -5px var(--vscode-scrollbar-shadow);
    border-left: 1px solid var(--vscode-diffEditor-border)
}

.monaco-diff-editor .diffViewport {
    background: var(--vscode-scrollbarSlider-background)
}

.monaco-diff-editor .diffViewport:hover {
    background: var(--vscode-scrollbarSlider-hoverBackground)
}

.monaco-diff-editor .diffViewport:active {
    background: var(--vscode-scrollbarSlider-activeBackground)
}

.monaco-list {
    position: relative;
    height: 100%;
    width: 100%;
    white-space: nowrap
}

.monaco-list.mouse-support {
    user-select: none;
    -webkit-user-select: none
}

.monaco-list>.monaco-scrollable-element {
    height: 100%
}

.monaco-list-rows {
    position: relative;
    width: 100%;
    height: 100%
}

.monaco-list.horizontal-scrolling .monaco-list-rows {
    width: auto;
    min-width: 100%
}

.monaco-list-row {
    position: absolute;
    box-sizing: border-box;
    overflow: hidden;
    width: 100%
}

.monaco-list.mouse-support .monaco-list-row {
    cursor: pointer;
    touch-action: none
}

.monaco-list-row.scrolling {
    display: none !important
}

.monaco-list.element-focused,
.monaco-list.selection-single,
.monaco-list.selection-multiple {
    outline: 0 !important
}

.monaco-drag-image {
    display: inline-block;
    padding: 1px 7px;
    border-radius: 10px;
    font-size: 12px;
    position: absolute;
    z-index: 1000
}

.monaco-list-type-filter-message {
    position: absolute;
    box-sizing: border-box;
    width: 100%;
    height: 100%;
    top: 0;
    left: 0;
    padding: 40px 1em 1em;
    text-align: center;
    white-space: normal;
    opacity: .7;
    pointer-events: none
}

.monaco-list-type-filter-message:empty {
    display: none
}

.monaco-select-box-dropdown-padding {
    --dropdown-padding-top: 1px;
    --dropdown-padding-bottom: 1px
}

.hc-black .monaco-select-box-dropdown-padding,
.hc-light .monaco-select-box-dropdown-padding {
    --dropdown-padding-top: 3px;
    --dropdown-padding-bottom: 4px
}

.monaco-select-box-dropdown-container {
    display: none;
    box-sizing: border-box
}

.monaco-select-box-dropdown-container>.select-box-details-pane>.select-box-description-markdown * {
    margin: 0
}

.monaco-select-box-dropdown-container>.select-box-details-pane>.select-box-description-markdown a:focus {
    outline: 1px solid -webkit-focus-ring-color;
    outline-offset: -1px
}

.monaco-select-box-dropdown-container>.select-box-details-pane>.select-box-description-markdown code {
    line-height: 15px;
    font-family: var(--monaco-monospace-font)
}

.monaco-select-box-dropdown-container.visible {
    display: flex;
    flex-direction: column;
    text-align: left;
    width: 1px;
    overflow: hidden;
    border-bottom-left-radius: 3px;
    border-bottom-right-radius: 3px
}

.monaco-select-box-dropdown-container>.select-box-dropdown-list-container {
    flex: 0 0 auto;
    align-self: flex-start;
    padding-top: var(--dropdown-padding-top);
    padding-bottom: var(--dropdown-padding-bottom);
    padding-left: 1px;
    padding-right: 1px;
    width: 100%;
    overflow: hidden;
    box-sizing: border-box
}

.monaco-select-box-dropdown-container>.select-box-details-pane {
    padding: 5px
}

.hc-black .monaco-select-box-dropdown-container>.select-box-dropdown-list-container {
    padding-top: var(--dropdown-padding-top);
    padding-bottom: var(--dropdown-padding-bottom)
}

.monaco-select-box-dropdown-container>.select-box-dropdown-list-container .monaco-list .monaco-list-row {
    cursor: pointer
}

.monaco-select-box-dropdown-container>.select-box-dropdown-list-container .monaco-list .monaco-list-row>.option-text {
    text-overflow: ellipsis;
    overflow: hidden;
    padding-left: 3.5px;
    white-space: nowrap;
    float: left
}

.monaco-select-box-dropdown-container>.select-box-dropdown-list-container .monaco-list .monaco-list-row>.option-detail {
    text-overflow: ellipsis;
    overflow: hidden;
    padding-left: 3.5px;
    white-space: nowrap;
    float: left;
    opacity: .7
}

.monaco-select-box-dropdown-container>.select-box-dropdown-list-container .monaco-list .monaco-list-row>.option-decorator-right {
    text-overflow: ellipsis;
    overflow: hidden;
    padding-right: 10px;
    white-space: nowrap;
    float: right
}

.monaco-select-box-dropdown-container>.select-box-dropdown-list-container .monaco-list .monaco-list-row>.visually-hidden {
    position: absolute;
    left: -10000px;
    top: auto;
    width: 1px;
    height: 1px;
    overflow: hidden
}

.monaco-select-box-dropdown-container>.select-box-dropdown-container-width-control {
    flex: 1 1 auto;
    align-self: flex-start;
    opacity: 0
}

.monaco-select-box-dropdown-container>.select-box-dropdown-container-width-control>.width-control-div {
    overflow: hidden;
    max-height: 0px
}

.monaco-select-box-dropdown-container>.select-box-dropdown-container-width-control>.width-control-div>.option-text-width-control {
    padding-left: 4px;
    padding-right: 8px;
    white-space: nowrap
}

.monaco-select-box {
    width: 100%;
    cursor: pointer;
    border-radius: 2px
}

.monaco-select-box-dropdown-container {
    font-size: 13px;
    font-weight: 400;
    text-transform: none
}

.monaco-action-bar .action-item.select-container {
    cursor: default
}

.monaco-action-bar .action-item .monaco-select-box {
    cursor: pointer;
    min-width: 100px;
    min-height: 18px;
    padding: 2px 23px 2px 8px
}

.mac .monaco-action-bar .action-item .monaco-select-box {
    font-size: 11px;
    border-radius: 5px
}

.monaco-action-bar {
    white-space: nowrap;
    height: 100%
}

.monaco-action-bar .actions-container {
    display: flex;
    margin: 0 auto;
    padding: 0;
    height: 100%;
    width: 100%;
    align-items: center
}

.monaco-action-bar.vertical .actions-container {
    display: inline-block
}

.monaco-action-bar .action-item {
    display: block;
    align-items: center;
    justify-content: center;
    cursor: pointer;
    position: relative
}

.monaco-action-bar .action-item.disabled {
    cursor: default
}

.monaco-action-bar .action-item .icon,
.monaco-action-bar .action-item .codicon {
    display: block
}

.monaco-action-bar .action-item .codicon {
    display: flex;
    align-items: center;
    width: 16px;
    height: 16px
}

.monaco-action-bar .action-label {
    display: flex;
    font-size: 11px;
    padding: 3px;
    border-radius: 5px
}

.monaco-action-bar .action-item.disabled .action-label,
.monaco-action-bar .action-item.disabled .action-label:before,
.monaco-action-bar .action-item.disabled .action-label:hover {
    opacity: .6
}

.monaco-action-bar.vertical {
    text-align: left
}

.monaco-action-bar.vertical .action-item {
    display: block
}

.monaco-action-bar.vertical .action-label.separator {
    display: block;
    border-bottom: 1px solid #bbb;
    padding-top: 1px;
    margin-left: .8em;
    margin-right: .8em
}

.monaco-action-bar .action-item .action-label.separator {
    width: 1px;
    height: 16px;
    margin: 5px 4px !important;
    cursor: default;
    min-width: 1px;
    padding: 0;
    background-color: #bbb
}

.secondary-actions .monaco-action-bar .action-label {
    margin-left: 6px
}

.monaco-action-bar .action-item.select-container {
    overflow: hidden;
    flex: 1;
    max-width: 170px;
    min-width: 60px;
    display: flex;
    align-items: center;
    justify-content: center;
    margin-right: 10px
}

.monaco-action-bar .action-item.action-dropdown-item {
    display: flex
}

.monaco-action-bar .action-item.action-dropdown-item>.action-dropdown-item-separator {
    display: flex;
    align-items: center;
    cursor: default
}

.monaco-action-bar .action-item.action-dropdown-item>.action-dropdown-item-separator>div {
    width: 1px
}

.monaco-diff-editor .diff-review-line-number {
    text-align: right;
    display: inline-block;
    color: var(--vscode-editorLineNumber-foreground)
}

.monaco-diff-editor .diff-review {
    position: absolute;
    user-select: none;
    -webkit-user-select: none;
    z-index: 99
}

.monaco-diff-editor .diff-review-summary {
    padding-left: 10px
}

.monaco-diff-editor .diff-review-shadow {
    position: absolute;
    box-shadow: var(--vscode-scrollbar-shadow) 0 -6px 6px -6px inset
}

.monaco-diff-editor .diff-review-row {
    white-space: pre
}

.monaco-diff-editor .diff-review-table {
    display: table;
    min-width: 100%
}

.monaco-diff-editor .diff-review-row {
    display: table-row;
    width: 100%
}

.monaco-diff-editor .diff-review-spacer {
    display: inline-block;
    width: 10px;
    vertical-align: middle
}

.monaco-diff-editor .diff-review-spacer>.codicon {
    font-size: 9px !important
}

.monaco-diff-editor .diff-review-actions {
    display: inline-block;
    position: absolute;
    right: 10px;
    top: 2px;
    z-index: 100
}

.monaco-diff-editor .diff-review-actions .action-label {
    width: 16px;
    height: 16px;
    margin: 2px 0
}

.context-view {
    position: absolute
}

.context-view.fixed {
    all: initial;
    font-family: inherit;
    font-size: 13px;
    position: fixed;
    color: inherit
}

.monaco-dropdown {
    height: 100%;
    padding: 0
}

.monaco-dropdown>.dropdown-label {
    cursor: pointer;
    height: 100%;
    display: flex;
    align-items: center;
    justify-content: center
}

.monaco-dropdown>.dropdown-label>.action-label.disabled {
    cursor: default
}

.monaco-dropdown-with-primary {
    display: flex !important;
    flex-direction: row;
    border-radius: 5px
}

.monaco-dropdown-with-primary>.action-container>.action-label {
    margin-right: 0
}

.monaco-dropdown-with-primary>.dropdown-action-container>.monaco-dropdown>.dropdown-label .codicon[class*=codicon-] {
    font-size: 12px;
    padding-left: 0;
    padding-right: 0;
    line-height: 16px;
    margin-left: -3px
}

.monaco-dropdown-with-primary>.dropdown-action-container>.monaco-dropdown>.dropdown-label>.action-label {
    display: block;
    background-size: 16px;
    background-position: center center;
    background-repeat: no-repeat
}

.monaco-action-bar .action-item.menu-entry .action-label.icon {
    width: 16px;
    height: 16px;
    background-repeat: no-repeat;
    background-position: 50%;
    background-size: 16px
}

.monaco-dropdown-with-default {
    display: flex !important;
    flex-direction: row;
    border-radius: 5px
}

.monaco-dropdown-with-default>.action-container>.action-label {
    margin-right: 0
}

.monaco-dropdown-with-default>.action-container.menu-entry>.action-label.icon {
    width: 16px;
    height: 16px;
    background-repeat: no-repeat;
    background-position: 50%;
    background-size: 16px
}

.monaco-dropdown-with-default>.dropdown-action-container>.monaco-dropdown>.dropdown-label .codicon[class*=codicon-] {
    font-size: 12px;
    padding-left: 0;
    padding-right: 0;
    line-height: 16px;
    margin-left: -3px
}

.monaco-dropdown-with-default>.dropdown-action-container>.monaco-dropdown>.dropdown-label>.action-label {
    display: block;
    background-size: 16px;
    background-position: center center;
    background-repeat: no-repeat
}

.quick-input-widget {
    font-size: 13px
}

.quick-input-widget .monaco-highlighted-label .highlight {
    color: #0066bf
}

.vs .quick-input-widget .monaco-list-row.focused .monaco-highlighted-label .highlight {
    color: #9dddff
}

.vs-dark .quick-input-widget .monaco-highlighted-label .highlight {
    color: #0097fb
}

.hc-black .quick-input-widget .monaco-highlighted-label .highlight {
    color: #f38518
}

.hc-light .quick-input-widget .monaco-highlighted-label .highlight {
    color: #0f4a85
}

.monaco-keybinding>.monaco-keybinding-key {
    background-color: #ddd6;
    border: solid 1px rgba(204, 204, 204, .4);
    border-bottom-color: #bbb6;
    box-shadow: inset 0 -1px #bbb6;
    color: #555
}

.hc-black .monaco-keybinding>.monaco-keybinding-key {
    background-color: transparent;
    border: solid 1px rgb(111, 195, 223);
    box-shadow: none;
    color: #fff
}

.hc-light .monaco-keybinding>.monaco-keybinding-key {
    background-color: transparent;
    border: solid 1px #0F4A85;
    box-shadow: none;
    color: #292929
}

.vs-dark .monaco-keybinding>.monaco-keybinding-key {
    background-color: #8080802b;
    border: solid 1px rgba(51, 51, 51, .6);
    border-bottom-color: #4449;
    box-shadow: inset 0 -1px #4449;
    color: #ccc
}

.monaco-split-view2 {
    position: relative;
    width: 100%;
    height: 100%
}

.monaco-split-view2>.sash-container {
    position: absolute;
    width: 100%;
    height: 100%;
    pointer-events: none
}

.monaco-split-view2>.sash-container>.monaco-sash {
    pointer-events: initial
}

.monaco-split-view2>.monaco-scrollable-element {
    width: 100%;
    height: 100%
}

.monaco-split-view2>.monaco-scrollable-element>.split-view-container {
    width: 100%;
    height: 100%;
    white-space: nowrap;
    position: relative
}

.monaco-split-view2>.monaco-scrollable-element>.split-view-container>.split-view-view {
    white-space: initial;
    position: absolute
}

.monaco-split-view2>.monaco-scrollable-element>.split-view-container>.split-view-view:not(.visible) {
    display: none
}

.monaco-split-view2.vertical>.monaco-scrollable-element>.split-view-container>.split-view-view {
    width: 100%
}

.monaco-split-view2.horizontal>.monaco-scrollable-element>.split-view-container>.split-view-view {
    height: 100%
}

.monaco-split-view2.separator-border>.monaco-scrollable-element>.split-view-container>.split-view-view:not(:first-child):before {
    content: " ";
    position: absolute;
    top: 0;
    left: 0;
    z-index: 5;
    pointer-events: none;
    background-color: var(--separator-border)
}

.monaco-split-view2.separator-border.horizontal>.monaco-scrollable-element>.split-view-container>.split-view-view:not(:first-child):before {
    height: 100%;
    width: 1px
}

.monaco-split-view2.separator-border.vertical>.monaco-scrollable-element>.split-view-container>.split-view-view:not(:first-child):before {
    height: 1px;
    width: 100%
}

.monaco-table {
    display: flex;
    flex-direction: column;
    position: relative;
    height: 100%;
    width: 100%;
    white-space: nowrap;
    overflow: hidden
}

.monaco-table>.monaco-split-view2 {
    border-bottom: 1px solid transparent
}

.monaco-table>.monaco-list {
    flex: 1
}

.monaco-table-tr {
    display: flex;
    height: 100%
}

.monaco-table-th {
    width: 100%;
    height: 100%;
    font-weight: 700;
    overflow: hidden;
    text-overflow: ellipsis
}

.monaco-table-th,
.monaco-table-td {
    box-sizing: border-box;
    flex-shrink: 0;
    overflow: hidden;
    white-space: nowrap;
    text-overflow: ellipsis
}

.monaco-table>.monaco-split-view2 .monaco-sash.vertical:before {
    content: "";
    position: absolute;
    left: calc(var(--vscode-sash-size) / 2);
    width: 0;
    border-left: 1px solid transparent
}

.monaco-workbench:not(.reduce-motion) .monaco-table>.monaco-split-view2,
.monaco-workbench:not(.reduce-motion) .monaco-table>.monaco-split-view2 .monaco-sash.vertical:before {
    transition: border-color .2s ease-out
}

.monaco-custom-toggle {
    margin-left: 2px;
    float: left;
    cursor: pointer;
    overflow: hidden;
    width: 20px;
    height: 20px;
    border-radius: 3px;
    border: 1px solid transparent;
    padding: 1px;
    box-sizing: border-box;
    user-select: none;
    -webkit-user-select: none
}

.monaco-custom-toggle:hover {
    background-color: var(--vscode-inputOption-hoverBackground)
}

.hc-black .monaco-custom-toggle:hover,
.hc-light .monaco-custom-toggle:hover {
    border: 1px dashed var(--vscode-focusBorder)
}

.hc-black .monaco-custom-toggle,
.hc-light .monaco-custom-toggle,
.hc-black .monaco-custom-toggle:hover,
.hc-light .monaco-custom-toggle:hover {
    background: none
}

.monaco-custom-toggle.monaco-checkbox {
    height: 18px;
    width: 18px;
    border: 1px solid transparent;
    border-radius: 3px;
    margin-right: 9px;
    margin-left: 0;
    padding: 0;
    opacity: 1;
    background-size: 16px !important
}

.monaco-custom-toggle.monaco-checkbox:not(.checked):before {
    visibility: hidden
}

.monaco-inputbox {
    position: relative;
    display: block;
    padding: 0;
    box-sizing: border-box;
    border-radius: 2px;
    font-size: inherit
}

.monaco-inputbox>.ibwrapper>.input,
.monaco-inputbox>.ibwrapper>.mirror {
    padding: 4px 6px
}

.monaco-inputbox>.ibwrapper {
    position: relative;
    width: 100%;
    height: 100%
}

.monaco-inputbox>.ibwrapper>.input {
    display: inline-block;
    box-sizing: border-box;
    width: 100%;
    height: 100%;
    line-height: inherit;
    border: none;
    font-family: inherit;
    font-size: inherit;
    resize: none;
    color: inherit
}

.monaco-inputbox>.ibwrapper>input {
    text-overflow: ellipsis
}

.monaco-inputbox>.ibwrapper>textarea.input {
    display: block;
    scrollbar-width: none;
    outline: none
}

.monaco-inputbox>.ibwrapper>textarea.input::-webkit-scrollbar {
    display: none
}

.monaco-inputbox>.ibwrapper>textarea.input.empty {
    white-space: nowrap
}

.monaco-inputbox>.ibwrapper>.mirror {
    position: absolute;
    display: inline-block;
    width: 100%;
    top: 0;
    left: 0;
    box-sizing: border-box;
    white-space: pre-wrap;
    visibility: hidden;
    word-wrap: break-word
}

.monaco-inputbox-container {
    text-align: right
}

.monaco-inputbox-container .monaco-inputbox-message {
    display: inline-block;
    overflow: hidden;
    text-align: left;
    width: 100%;
    box-sizing: border-box;
    padding: .4em;
    font-size: 12px;
    line-height: 17px;
    margin-top: -1px;
    word-wrap: break-word
}

.monaco-inputbox .monaco-action-bar {
    position: absolute;
    right: 2px;
    top: 4px
}

.monaco-inputbox .monaco-action-bar .action-item {
    margin-left: 2px
}

.monaco-inputbox .monaco-action-bar .action-item .codicon {
    background-repeat: no-repeat;
    width: 16px;
    height: 16px
}

.monaco-findInput {
    position: relative
}

.monaco-findInput .monaco-inputbox {
    font-size: 13px;
    width: 100%
}

.monaco-findInput>.controls {
    position: absolute;
    top: 3px;
    right: 2px
}

.vs .monaco-findInput.disabled {
    background-color: #e1e1e1
}

.vs-dark .monaco-findInput.disabled {
    background-color: #333
}

.monaco-findInput.highlight-0 .controls,
.hc-light .monaco-findInput.highlight-0 .controls {
    animation: monaco-findInput-highlight-0 .1s linear 0s
}

.monaco-findInput.highlight-1 .controls,
.hc-light .monaco-findInput.highlight-1 .controls {
    animation: monaco-findInput-highlight-1 .1s linear 0s
}

.hc-black .monaco-findInput.highlight-0 .controls,
.vs-dark .monaco-findInput.highlight-0 .controls {
    animation: monaco-findInput-highlight-dark-0 .1s linear 0s
}

.hc-black .monaco-findInput.highlight-1 .controls,
.vs-dark .monaco-findInput.highlight-1 .controls {
    animation: monaco-findInput-highlight-dark-1 .1s linear 0s
}

@keyframes monaco-findInput-highlight-0 {
    0% {
        background: rgba(253, 255, 0, .8)
    }

    to {
        background: transparent
    }
}

@keyframes monaco-findInput-highlight-1 {
    0% {
        background: rgba(253, 255, 0, .8)
    }

    99% {
        background: transparent
    }
}

@keyframes monaco-findInput-highlight-dark-0 {
    0% {
        background: rgba(255, 255, 255, .44)
    }

    to {
        background: transparent
    }
}

@keyframes monaco-findInput-highlight-dark-1 {
    0% {
        background: rgba(255, 255, 255, .44)
    }

    99% {
        background: transparent
    }
}

.monaco-tl-row {
    display: flex;
    height: 100%;
    align-items: center;
    position: relative
}

.monaco-tl-row.disabled {
    cursor: default
}

.monaco-tl-indent {
    height: 100%;
    position: absolute;
    top: 0;
    left: 16px;
    pointer-events: none
}

.hide-arrows .monaco-tl-indent {
    left: 12px
}

.monaco-tl-indent>.indent-guide {
    display: inline-block;
    box-sizing: border-box;
    height: 100%;
    border-left: 1px solid transparent
}

.monaco-workbench:not(.reduce-motion) .monaco-tl-indent>.indent-guide {
    transition: border-color .1s linear
}

.monaco-tl-twistie,
.monaco-tl-contents {
    height: 100%
}

.monaco-tl-twistie {
    font-size: 10px;
    text-align: right;
    padding-right: 6px;
    flex-shrink: 0;
    width: 16px;
    display: flex !important;
    align-items: center;
    justify-content: center;
    transform: translate(3px)
}

.monaco-tl-contents {
    flex: 1;
    overflow: hidden
}

.monaco-tl-twistie:before {
    border-radius: 20px
}

.monaco-tl-twistie.collapsed:before {
    transform: rotate(-90deg)
}

.monaco-tl-twistie.codicon-tree-item-loading:before {
    animation: codicon-spin 1.25s steps(30) infinite
}

.monaco-tree-type-filter {
    position: absolute;
    top: 0;
    display: flex;
    padding: 3px;
    max-width: 200px;
    z-index: 100;
    margin: 0 6px;
    border: 1px solid var(--vscode-widget-border);
    border-bottom-left-radius: 4px;
    border-bottom-right-radius: 4px
}

.monaco-workbench:not(.reduce-motion) .monaco-tree-type-filter {
    transition: top .3s
}

.monaco-tree-type-filter.disabled {
    top: -40px !important
}

.monaco-tree-type-filter-grab {
    display: flex !important;
    align-items: center;
    justify-content: center;
    cursor: grab;
    margin-right: 2px
}

.monaco-tree-type-filter-grab.grabbing {
    cursor: grabbing
}

.monaco-tree-type-filter-input {
    flex: 1
}

.monaco-tree-type-filter-input .monaco-inputbox {
    height: 23px
}

.monaco-tree-type-filter-input .monaco-inputbox>.ibwrapper>.input,
.monaco-tree-type-filter-input .monaco-inputbox>.ibwrapper>.mirror {
    padding: 2px 4px
}

.monaco-tree-type-filter-input .monaco-findInput>.controls {
    top: 2px
}

.monaco-tree-type-filter-actionbar {
    margin-left: 4px
}

.monaco-tree-type-filter-actionbar .monaco-action-bar .action-label {
    padding: 2px
}

.monaco-text-button {
    box-sizing: border-box;
    display: flex;
    width: 100%;
    padding: 4px;
    border-radius: 2px;
    text-align: center;
    cursor: pointer;
    justify-content: center;
    align-items: center;
    border: 1px solid var(--vscode-button-border, transparent);
    line-height: 18px
}

.monaco-text-button:focus {
    outline-offset: 2px !important
}

.monaco-text-button:hover {
    text-decoration: none !important
}

.monaco-button.disabled:focus,
.monaco-button.disabled {
    opacity: .4 !important;
    cursor: default
}

.monaco-text-button .codicon {
    margin: 0 .2em;
    color: inherit !important
}

.monaco-text-button.monaco-text-button-with-short-label {
    flex-direction: row;
    flex-wrap: wrap;
    padding: 0 4px;
    overflow: hidden;
    height: 28px
}

.monaco-text-button.monaco-text-button-with-short-label>.monaco-button-label {
    flex-basis: 100%
}

.monaco-text-button.monaco-text-button-with-short-label>.monaco-button-label-short {
    flex-grow: 1;
    width: 0;
    overflow: hidden
}

.monaco-text-button.monaco-text-button-with-short-label>.monaco-button-label,
.monaco-text-button.monaco-text-button-with-short-label>.monaco-button-label-short {
    display: flex;
    justify-content: center;
    align-items: center;
    font-weight: 400;
    font-style: inherit;
    padding: 4px 0
}

.monaco-button-dropdown {
    display: flex;
    cursor: pointer
}

.monaco-button-dropdown.disabled {
    cursor: default
}

.monaco-button-dropdown>.monaco-button:focus {
    outline-offset: -1px !important
}

.monaco-button-dropdown.disabled>.monaco-button.disabled,
.monaco-button-dropdown.disabled>.monaco-button.disabled:focus,
.monaco-button-dropdown.disabled>.monaco-button-dropdown-separator {
    opacity: .4 !important
}

.monaco-button-dropdown>.monaco-button.monaco-text-button {
    border-right-width: 0 !important
}

.monaco-button-dropdown .monaco-button-dropdown-separator {
    padding: 4px 0;
    cursor: default
}

.monaco-button-dropdown .monaco-button-dropdown-separator>div {
    height: 100%;
    width: 1px
}

.monaco-button-dropdown>.monaco-button.monaco-dropdown-button {
    border: 1px solid var(--vscode-button-border, transparent);
    border-left-width: 0 !important;
    border-radius: 0 2px 2px 0
}

.monaco-button-dropdown>.monaco-button.monaco-text-button {
    border-radius: 2px 0 0 2px
}

.monaco-description-button {
    display: flex;
    flex-direction: column;
    align-items: center;
    margin: 4px 5px
}

.monaco-description-button .monaco-button-description {
    font-style: italic;
    font-size: 11px;
    padding: 4px 20px
}

.monaco-description-button .monaco-button-label,
.monaco-description-button .monaco-button-description {
    display: flex;
    justify-content: center;
    align-items: center
}

.monaco-description-button .monaco-button-label>.codicon,
.monaco-description-button .monaco-button-description>.codicon {
    margin: 0 .2em;
    color: inherit !important
}

.monaco-button.default-colors,
.monaco-button-dropdown.default-colors>.monaco-button {
    color: var(--vscode-button-foreground);
    background-color: var(--vscode-button-background)
}

.monaco-button.default-colors:hover,
.monaco-button-dropdown.default-colors>.monaco-button:hover {
    background-color: var(--vscode-button-hoverBackground)
}

.monaco-button.default-colors.secondary,
.monaco-button-dropdown.default-colors>.monaco-button.secondary {
    color: var(--vscode-button-secondaryForeground);
    background-color: var(--vscode-button-secondaryBackground)
}

.monaco-button.default-colors.secondary:hover,
.monaco-button-dropdown.default-colors>.monaco-button.secondary:hover {
    background-color: var(--vscode-button-secondaryHoverBackground)
}

.monaco-button-dropdown.default-colors .monaco-button-dropdown-separator {
    background-color: var(--vscode-button-background);
    border-top: 1px solid var(--vscode-button-border);
    border-bottom: 1px solid var(--vscode-button-border)
}

.monaco-button-dropdown.default-colors .monaco-button.secondary+.monaco-button-dropdown-separator {
    background-color: var(--vscode-button-secondaryBackground)
}

.monaco-button-dropdown.default-colors .monaco-button-dropdown-separator>div {
    background-color: var(--vscode-button-separator)
}

.monaco-count-badge {
    padding: 3px 6px;
    border-radius: 11px;
    font-size: 11px;
    min-width: 18px;
    min-height: 18px;
    line-height: 11px;
    font-weight: 400;
    text-align: center;
    display: inline-block;
    box-sizing: border-box
}

.monaco-count-badge.long {
    padding: 2px 3px;
    border-radius: 2px;
    min-height: auto;
    line-height: normal
}

.monaco-progress-container {
    width: 100%;
    height: 5px;
    overflow: hidden
}

.monaco-progress-container .progress-bit {
    width: 2%;
    height: 5px;
    position: absolute;
    left: 0;
    display: none
}

.monaco-progress-container.active .progress-bit {
    display: inherit
}

.monaco-progress-container.discrete .progress-bit {
    left: 0;
    transition: width .1s linear
}

.monaco-progress-container.discrete.done .progress-bit {
    width: 100%
}

.monaco-progress-container.infinite .progress-bit {
    animation-name: progress;
    animation-duration: 4s;
    animation-iteration-count: infinite;
    transform: translateZ(0);
    animation-timing-function: linear
}

.monaco-progress-container.infinite.infinite-long-running .progress-bit {
    animation-timing-function: steps(100)
}

@keyframes progress {
    0% {
        transform: translate(0) scaleX(1)
    }

    50% {
        transform: translate(2500%) scaleX(3)
    }

    to {
        transform: translate(4900%) scaleX(1)
    }
}

.quick-input-widget {
    position: absolute;
    width: 600px;
    z-index: 2550;
    left: 50%;
    margin-left: -300px;
    -webkit-app-region: no-drag;
    border-radius: 6px
}

.quick-input-titlebar {
    display: flex;
    align-items: center;
    border-top-left-radius: 5px;
    border-top-right-radius: 5px
}

.quick-input-left-action-bar {
    display: flex;
    margin-left: 4px;
    flex: 1
}

.quick-input-title {
    padding: 3px 0;
    text-align: center;
    text-overflow: ellipsis;
    overflow: hidden
}

.quick-input-right-action-bar {
    display: flex;
    margin-right: 4px;
    flex: 1
}

.quick-input-right-action-bar>.actions-container {
    justify-content: flex-end
}

.quick-input-titlebar .monaco-action-bar .action-label.codicon {
    background-position: center;
    background-repeat: no-repeat;
    padding: 2px
}

.quick-input-description {
    margin: 6px
}

.quick-input-header .quick-input-description {
    margin: 4px 2px
}

.quick-input-header {
    display: flex;
    padding: 8px 6px 6px
}

.quick-input-widget.hidden-input .quick-input-header {
    padding: 0;
    margin-bottom: 0
}

.quick-input-and-message {
    display: flex;
    flex-direction: column;
    flex-grow: 1;
    min-width: 0;
    position: relative
}

.quick-input-check-all {
    align-self: center;
    margin: 0
}

.quick-input-filter {
    flex-grow: 1;
    display: flex;
    position: relative
}

.quick-input-box {
    flex-grow: 1
}

.quick-input-widget.show-checkboxes .quick-input-box,
.quick-input-widget.show-checkboxes .quick-input-message {
    margin-left: 5px
}

.quick-input-visible-count {
    position: absolute;
    left: -10000px
}

.quick-input-count {
    align-self: center;
    position: absolute;
    right: 4px;
    display: flex;
    align-items: center
}

.quick-input-count .monaco-count-badge {
    vertical-align: middle;
    padding: 2px 4px;
    border-radius: 2px;
    min-height: auto;
    line-height: normal
}

.quick-input-action {
    margin-left: 6px
}

.quick-input-action .monaco-text-button {
    font-size: 11px;
    padding: 0 6px;
    display: flex;
    height: 25px;
    align-items: center
}

.quick-input-message {
    margin-top: -1px;
    padding: 5px;
    overflow-wrap: break-word
}

.quick-input-message>.codicon {
    margin: 0 .2em;
    vertical-align: text-bottom
}

.quick-input-message a {
    color: inherit
}

.quick-input-progress.monaco-progress-container {
    position: relative
}

.quick-input-progress.monaco-progress-container,
.quick-input-progress.monaco-progress-container .progress-bit {
    height: 2px
}

.quick-input-list {
    line-height: 22px
}

.quick-input-widget.hidden-input .quick-input-list {
    margin-top: 4px;
    padding-bottom: 4px
}

.quick-input-list .monaco-list {
    overflow: hidden;
    max-height: 440px;
    padding-bottom: 5px
}

.quick-input-list .monaco-scrollable-element {
    padding: 0 5px
}

.quick-input-list .quick-input-list-entry {
    box-sizing: border-box;
    overflow: hidden;
    display: flex;
    height: 100%;
    padding: 0 6px
}

.quick-input-list .quick-input-list-entry.quick-input-list-separator-border {
    border-top-width: 1px;
    border-top-style: solid
}

.quick-input-list .monaco-list-row {
    border-radius: 3px
}

.quick-input-list .monaco-list-row[data-index="0"] .quick-input-list-entry.quick-input-list-separator-border {
    border-top-style: none
}

.quick-input-list .quick-input-list-label {
    overflow: hidden;
    display: flex;
    height: 100%;
    flex: 1
}

.quick-input-list .quick-input-list-checkbox {
    align-self: center;
    margin: 0
}

.quick-input-list .quick-input-list-icon {
    background-size: 16px;
    background-position: left center;
    background-repeat: no-repeat;
    padding-right: 6px;
    width: 16px;
    height: 22px;
    display: flex;
    align-items: center;
    justify-content: center
}

.quick-input-list .quick-input-list-rows {
    overflow: hidden;
    text-overflow: ellipsis;
    display: flex;
    flex-direction: column;
    height: 100%;
    flex: 1;
    margin-left: 5px
}

.quick-input-widget.show-checkboxes .quick-input-list .quick-input-list-rows {
    margin-left: 10px
}

.quick-input-widget .quick-input-list .quick-input-list-checkbox {
    display: none
}

.quick-input-widget.show-checkboxes .quick-input-list .quick-input-list-checkbox {
    display: inline
}

.quick-input-list .quick-input-list-rows>.quick-input-list-row {
    display: flex;
    align-items: center
}

.quick-input-list .quick-input-list-rows>.quick-input-list-row .monaco-icon-label,
.quick-input-list .quick-input-list-rows>.quick-input-list-row .monaco-icon-label .monaco-icon-label-container>.monaco-icon-name-container {
    flex: 1
}

.quick-input-list .quick-input-list-rows>.quick-input-list-row .codicon[class*=codicon-] {
    vertical-align: text-bottom
}

.quick-input-list .quick-input-list-rows .monaco-highlighted-label>span {
    opacity: 1
}

.quick-input-list .quick-input-list-entry .quick-input-list-entry-keybinding {
    margin-right: 8px
}

.quick-input-list .quick-input-list-label-meta {
    opacity: .7;
    line-height: normal;
    text-overflow: ellipsis;
    overflow: hidden
}

.quick-input-list .monaco-highlighted-label .highlight {
    font-weight: 700
}

.quick-input-list .quick-input-list-entry .quick-input-list-separator {
    margin-right: 4px
}

.quick-input-list .quick-input-list-entry-action-bar {
    display: flex;
    flex: 0;
    overflow: visible
}

.quick-input-list .quick-input-list-entry-action-bar .action-label {
    display: none
}

.quick-input-list .quick-input-list-entry-action-bar .action-label.codicon {
    margin-right: 4px;
    padding: 0 2px 2px
}

.quick-input-list .quick-input-list-entry-action-bar {
    margin-top: 1px
}

.quick-input-list .quick-input-list-entry-action-bar {
    margin-right: 4px
}

.quick-input-list .quick-input-list-entry .quick-input-list-entry-action-bar .action-label.always-visible,
.quick-input-list .quick-input-list-entry:hover .quick-input-list-entry-action-bar .action-label,
.quick-input-list .monaco-list-row.focused .quick-input-list-entry-action-bar .action-label {
    display: flex
}

.quick-input-list .monaco-list-row.focused .monaco-keybinding-key,
.quick-input-list .monaco-list-row.focused .quick-input-list-entry .quick-input-list-separator {
    color: inherit
}

.quick-input-list .monaco-list-row.focused .monaco-keybinding-key {
    background: none
}

.monaco-icon-label {
    display: flex;
    overflow: hidden;
    text-overflow: ellipsis
}

.monaco-icon-label:before {
    background-size: 16px;
    background-position: left center;
    background-repeat: no-repeat;
    padding-right: 6px;
    width: 16px;
    height: 22px;
    line-height: inherit !important;
    display: inline-block;
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
    vertical-align: top;
    flex-shrink: 0
}

.monaco-icon-label-container.disabled {
    color: var(--vscode-disabledForeground)
}

.monaco-icon-label>.monaco-icon-label-container {
    min-width: 0;
    overflow: hidden;
    text-overflow: ellipsis;
    flex: 1
}

.monaco-icon-label>.monaco-icon-label-container>.monaco-icon-name-container>.label-name {
    color: inherit;
    white-space: pre
}

.monaco-icon-label>.monaco-icon-label-container>.monaco-icon-name-container>.label-name>.label-separator {
    margin: 0 2px;
    opacity: .5
}

.monaco-icon-label>.monaco-icon-label-container>.monaco-icon-description-container>.label-description {
    opacity: .7;
    margin-left: .5em;
    font-size: .9em;
    white-space: pre
}

.monaco-icon-label.nowrap>.monaco-icon-label-container>.monaco-icon-description-container>.label-description {
    white-space: nowrap
}

.vs .monaco-icon-label>.monaco-icon-label-container>.monaco-icon-description-container>.label-description {
    opacity: .95
}

.monaco-icon-label.italic>.monaco-icon-label-container>.monaco-icon-name-container>.label-name,
.monaco-icon-label.italic>.monaco-icon-label-container>.monaco-icon-description-container>.label-description {
    font-style: italic
}

.monaco-icon-label.deprecated {
    text-decoration: line-through;
    opacity: .66
}

.monaco-icon-label.italic:after {
    font-style: italic
}

.monaco-icon-label.strikethrough>.monaco-icon-label-container>.monaco-icon-name-container>.label-name,
.monaco-icon-label.strikethrough>.monaco-icon-label-container>.monaco-icon-description-container>.label-description {
    text-decoration: line-through
}

.monaco-icon-label:after {
    opacity: .75;
    font-size: 90%;
    font-weight: 600;
    margin: auto 16px 0 5px;
    text-align: center
}

.monaco-list:focus .selected .monaco-icon-label,
.monaco-list:focus .selected .monaco-icon-label:after {
    color: inherit !important
}

.monaco-list-row.focused.selected .label-description,
.monaco-list-row.selected .label-description {
    opacity: .8
}

.monaco-keybinding {
    display: flex;
    align-items: center;
    line-height: 10px
}

.monaco-keybinding>.monaco-keybinding-key {
    display: inline-block;
    border-style: solid;
    border-width: 1px;
    border-radius: 3px;
    vertical-align: middle;
    font-size: 11px;
    padding: 3px 5px;
    margin: 0 2px
}

.monaco-keybinding>.monaco-keybinding-key:first-child {
    margin-left: 0
}

.monaco-keybinding>.monaco-keybinding-key:last-child {
    margin-right: 0
}

.monaco-keybinding>.monaco-keybinding-key-separator {
    display: inline-block
}

.monaco-keybinding>.monaco-keybinding-key-chord-separator {
    width: 6px
}

.monaco-editor .diff-hidden-lines-widget {
    width: 100%
}

.monaco-editor .diff-hidden-lines {
    height: 0px;
    transform: translateY(-10px);
    font-size: 13px;
    line-height: 14px
}

.monaco-editor .diff-hidden-lines:not(.dragging) .top:hover,
.diff-hidden-lines:not(.dragging) .bottom:hover,
.diff-hidden-lines .top.dragging,
.diff-hidden-lines .bottom.dragging {
    background-color: var(--vscode-focusBorder)
}

.monaco-editor .diff-hidden-lines .top,
.diff-hidden-lines .bottom {
    transition: background-color .1s ease-out;
    height: 4px;
    background-color: transparent;
    background-clip: padding-box;
    border-bottom: 2px solid transparent;
    border-top: 4px solid transparent;
    cursor: ns-resize
}

.monaco-editor .diff-hidden-lines .top {
    transform: translateY(4px)
}

.monaco-editor .diff-hidden-lines .bottom {
    transform: translateY(-6px)
}

.monaco-editor .diff-unchanged-lines {
    background: var(--vscode-diffEditor-unchangedCodeBackground)
}

.monaco-editor .noModificationsOverlay {
    z-index: 1;
    background: var(--vscode-editor-background);
    display: flex;
    justify-content: center;
    align-items: center
}

.monaco-editor .diff-hidden-lines .center {
    background: var(--vscode-diffEditor-unchangedRegionBackground);
    color: var(--vscode-diffEditor-unchangedRegionForeground);
    overflow: hidden;
    display: block;
    text-overflow: ellipsis;
    white-space: nowrap;
    height: 24px
}

.monaco-editor .diff-hidden-lines .center span.codicon {
    vertical-align: middle
}

.monaco-editor .diff-hidden-lines .center a:hover .codicon {
    cursor: pointer;
    color: var(--vscode-editorLink-activeForeground) !important
}

.monaco-editor .movedOriginal,
.monaco-editor .movedModified {
    border: 2px solid var(--vscode-diffEditor-move-border)
}

.monaco-diff-editor .moved-blocks-lines {
    position: absolute;
    pointer-events: none
}

.monaco-diff-editor .moved-blocks-lines path {
    fill: none;
    stroke: var(--vscode-diffEditor-move-border);
    stroke-width: 2
}

.monaco-editor .char-delete.diff-range-empty {
    margin-left: -1px;
    border-left: solid var(--vscode-diffEditor-removedTextBackground) 3px
}

.monaco-editor .char-insert.diff-range-empty {
    border-left: solid var(--vscode-diffEditor-insertedTextBackground) 3px
}

.monaco-editor .fold-unchanged {
    cursor: pointer
}

.monaco-editor .selection-anchor {
    background-color: #007acc;
    width: 2px !important
}

.monaco-editor .bracket-match {
    box-sizing: border-box;
    background-color: var(--vscode-editorBracketMatch-background);
    border: 1px solid var(--vscode-editorBracketMatch-border)
}

@font-face {
    font-family: codicon;
    font-display: block;
    src: url(data:font/ttf;base64, ) format("truetype")
}

.codicon[class*=codicon-] {
    font: 16px/1 codicon;
    display: inline-block;
    text-decoration: none;
    text-rendering: auto;
    text-align: center;
    text-transform: none;
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
    user-select: none;
    -webkit-user-select: none
}

.codicon-wrench-subaction {
    opacity: .5
}

@keyframes codicon-spin {
    to {
        transform: rotate(360deg)
    }
}

.codicon-sync.codicon-modifier-spin,
.codicon-loading.codicon-modifier-spin,
.codicon-gear.codicon-modifier-spin,
.codicon-notebook-state-executing.codicon-modifier-spin {
    animation: codicon-spin 1.5s steps(30) infinite
}

.codicon-modifier-disabled {
    opacity: .4
}

.codicon-loading,
.codicon-tree-item-loading:before {
    animation-duration: 1s !important;
    animation-timing-function: cubic-bezier(.53, .21, .29, .67) !important
}

.monaco-editor .codicon.codicon-symbol-array,
.monaco-workbench .codicon.codicon-symbol-array {
    color: var(--vscode-symbolIcon-arrayForeground)
}

.monaco-editor .codicon.codicon-symbol-boolean,
.monaco-workbench .codicon.codicon-symbol-boolean {
    color: var(--vscode-symbolIcon-booleanForeground)
}

.monaco-editor .codicon.codicon-symbol-class,
.monaco-workbench .codicon.codicon-symbol-class {
    color: var(--vscode-symbolIcon-classForeground)
}

.monaco-editor .codicon.codicon-symbol-method,
.monaco-workbench .codicon.codicon-symbol-method {
    color: var(--vscode-symbolIcon-methodForeground)
}

.monaco-editor .codicon.codicon-symbol-color,
.monaco-workbench .codicon.codicon-symbol-color {
    color: var(--vscode-symbolIcon-colorForeground)
}

.monaco-editor .codicon.codicon-symbol-constant,
.monaco-workbench .codicon.codicon-symbol-constant {
    color: var(--vscode-symbolIcon-constantForeground)
}

.monaco-editor .codicon.codicon-symbol-constructor,
.monaco-workbench .codicon.codicon-symbol-constructor {
    color: var(--vscode-symbolIcon-constructorForeground)
}

.monaco-editor .codicon.codicon-symbol-value,
.monaco-workbench .codicon.codicon-symbol-value,
.monaco-editor .codicon.codicon-symbol-enum,
.monaco-workbench .codicon.codicon-symbol-enum {
    color: var(--vscode-symbolIcon-enumeratorForeground)
}

.monaco-editor .codicon.codicon-symbol-enum-member,
.monaco-workbench .codicon.codicon-symbol-enum-member {
    color: var(--vscode-symbolIcon-enumeratorMemberForeground)
}

.monaco-editor .codicon.codicon-symbol-event,
.monaco-workbench .codicon.codicon-symbol-event {
    color: var(--vscode-symbolIcon-eventForeground)
}

.monaco-editor .codicon.codicon-symbol-field,
.monaco-workbench .codicon.codicon-symbol-field {
    color: var(--vscode-symbolIcon-fieldForeground)
}

.monaco-editor .codicon.codicon-symbol-file,
.monaco-workbench .codicon.codicon-symbol-file {
    color: var(--vscode-symbolIcon-fileForeground)
}

.monaco-editor .codicon.codicon-symbol-folder,
.monaco-workbench .codicon.codicon-symbol-folder {
    color: var(--vscode-symbolIcon-folderForeground)
}

.monaco-editor .codicon.codicon-symbol-function,
.monaco-workbench .codicon.codicon-symbol-function {
    color: var(--vscode-symbolIcon-functionForeground)
}

.monaco-editor .codicon.codicon-symbol-interface,
.monaco-workbench .codicon.codicon-symbol-interface {
    color: var(--vscode-symbolIcon-interfaceForeground)
}

.monaco-editor .codicon.codicon-symbol-key,
.monaco-workbench .codicon.codicon-symbol-key {
    color: var(--vscode-symbolIcon-keyForeground)
}

.monaco-editor .codicon.codicon-symbol-keyword,
.monaco-workbench .codicon.codicon-symbol-keyword {
    color: var(--vscode-symbolIcon-keywordForeground)
}

.monaco-editor .codicon.codicon-symbol-module,
.monaco-workbench .codicon.codicon-symbol-module {
    color: var(--vscode-symbolIcon-moduleForeground)
}

.monaco-editor .codicon.codicon-symbol-namespace,
.monaco-workbench .codicon.codicon-symbol-namespace {
    color: var(--vscode-symbolIcon-namespaceForeground)
}

.monaco-editor .codicon.codicon-symbol-null,
.monaco-workbench .codicon.codicon-symbol-null {
    color: var(--vscode-symbolIcon-nullForeground)
}

.monaco-editor .codicon.codicon-symbol-number,
.monaco-workbench .codicon.codicon-symbol-number {
    color: var(--vscode-symbolIcon-numberForeground)
}

.monaco-editor .codicon.codicon-symbol-object,
.monaco-workbench .codicon.codicon-symbol-object {
    color: var(--vscode-symbolIcon-objectForeground)
}

.monaco-editor .codicon.codicon-symbol-operator,
.monaco-workbench .codicon.codicon-symbol-operator {
    color: var(--vscode-symbolIcon-operatorForeground)
}

.monaco-editor .codicon.codicon-symbol-package,
.monaco-workbench .codicon.codicon-symbol-package {
    color: var(--vscode-symbolIcon-packageForeground)
}

.monaco-editor .codicon.codicon-symbol-property,
.monaco-workbench .codicon.codicon-symbol-property {
    color: var(--vscode-symbolIcon-propertyForeground)
}

.monaco-editor .codicon.codicon-symbol-reference,
.monaco-workbench .codicon.codicon-symbol-reference {
    color: var(--vscode-symbolIcon-referenceForeground)
}

.monaco-editor .codicon.codicon-symbol-snippet,
.monaco-workbench .codicon.codicon-symbol-snippet {
    color: var(--vscode-symbolIcon-snippetForeground)
}

.monaco-editor .codicon.codicon-symbol-string,
.monaco-workbench .codicon.codicon-symbol-string {
    color: var(--vscode-symbolIcon-stringForeground)
}

.monaco-editor .codicon.codicon-symbol-struct,
.monaco-workbench .codicon.codicon-symbol-struct {
    color: var(--vscode-symbolIcon-structForeground)
}

.monaco-editor .codicon.codicon-symbol-text,
.monaco-workbench .codicon.codicon-symbol-text {
    color: var(--vscode-symbolIcon-textForeground)
}

.monaco-editor .codicon.codicon-symbol-type-parameter,
.monaco-workbench .codicon.codicon-symbol-type-parameter {
    color: var(--vscode-symbolIcon-typeParameterForeground)
}

.monaco-editor .codicon.codicon-symbol-unit,
.monaco-workbench .codicon.codicon-symbol-unit {
    color: var(--vscode-symbolIcon-unitForeground)
}

.monaco-editor .codicon.codicon-symbol-variable,
.monaco-workbench .codicon.codicon-symbol-variable {
    color: var(--vscode-symbolIcon-variableForeground)
}

.monaco-editor .lightBulbWidget {
    display: flex;
    align-items: center;
    justify-content: center
}

.monaco-editor .lightBulbWidget:hover {
    cursor: pointer
}

.monaco-editor .lightBulbWidget.codicon-light-bulb {
    color: var(--vscode-editorLightBulb-foreground)
}

.monaco-editor .lightBulbWidget.codicon-lightbulb-autofix {
    color: var(--vscode-editorLightBulbAutoFix-foreground, var(--vscode-editorLightBulb-foreground))
}

.monaco-editor .lightBulbWidget:before {
    position: relative;
    z-index: 2
}

.monaco-editor .lightBulbWidget:after {
    position: absolute;
    top: 0;
    left: 0;
    content: "";
    display: block;
    width: 100%;
    height: 100%;
    opacity: .3;
    background-color: var(--vscode-editor-background);
    z-index: 1
}

.monaco-editor .monaco-editor-overlaymessage {
    padding-bottom: 8px;
    z-index: 10000
}

.monaco-editor .monaco-editor-overlaymessage.below {
    padding-bottom: 0;
    padding-top: 8px;
    z-index: 10000
}

@keyframes fadeIn {
    0% {
        opacity: 0
    }

    to {
        opacity: 1
    }
}

.monaco-editor .monaco-editor-overlaymessage.fadeIn {
    animation: fadeIn .15s ease-out
}

@keyframes fadeOut {
    0% {
        opacity: 1
    }

    to {
        opacity: 0
    }
}

.monaco-editor .monaco-editor-overlaymessage.fadeOut {
    animation: fadeOut .1s ease-out
}

.monaco-editor .monaco-editor-overlaymessage .message {
    padding: 2px 4px;
    color: var(--vscode-editorHoverWidget-foreground);
    background-color: var(--vscode-editorHoverWidget-background);
    border: 1px solid var(--vscode-inputValidation-infoBorder);
    border-radius: 3px
}

.monaco-editor .monaco-editor-overlaymessage .message p {
    margin-block: 0px
}

.monaco-editor .monaco-editor-overlaymessage .message a {
    color: var(--vscode-textLink-foreground)
}

.monaco-editor .monaco-editor-overlaymessage .message a:hover {
    color: var(--vscode-textLink-activeForeground)
}

.monaco-editor.hc-black .monaco-editor-overlaymessage .message,
.monaco-editor.hc-light .monaco-editor-overlaymessage .message {
    border-width: 2px
}

.monaco-editor .monaco-editor-overlaymessage .anchor {
    width: 0 !important;
    height: 0 !important;
    border-color: transparent;
    border-style: solid;
    z-index: 1000;
    border-width: 8px;
    position: absolute;
    left: 2px
}

.monaco-editor .monaco-editor-overlaymessage .anchor.top {
    border-bottom-color: var(--vscode-inputValidation-infoBorder)
}

.monaco-editor .monaco-editor-overlaymessage .anchor.below {
    border-top-color: var(--vscode-inputValidation-infoBorder)
}

.monaco-editor .monaco-editor-overlaymessage:not(.below) .anchor.top,
.monaco-editor .monaco-editor-overlaymessage.below .anchor.below {
    display: none
}

.monaco-editor .monaco-editor-overlaymessage.below .anchor.top {
    display: inherit;
    top: -8px
}

.monaco-editor .rendered-markdown kbd {
    background-color: var(--vscode-keybindingLabel-background);
    color: var(--vscode-keybindingLabel-foreground);
    border-style: solid;
    border-width: 1px;
    border-radius: 3px;
    border-color: var(--vscode-keybindingLabel-border);
    border-bottom-color: var(--vscode-keybindingLabel-bottomBorder);
    box-shadow: inset 0 -1px 0 var(--vscode-widget-shadow);
    vertical-align: middle;
    padding: 1px 3px
}

.action-widget {
    font-size: 13px;
    border-radius: 0;
    min-width: 160px;
    max-width: 500px;
    z-index: 40;
    display: block;
    width: 100%;
    border: 1px solid var(--vscode-editorWidget-border) !important;
    background-color: var(--vscode-editorWidget-background);
    color: var(--vscode-editorWidget-foreground)
}

.context-view-block {
    position: fixed;
    cursor: initial;
    left: 0;
    top: 0;
    width: 100%;
    height: 100%;
    z-index: -1
}

.context-view-pointerBlock {
    position: fixed;
    cursor: initial;
    left: 0;
    top: 0;
    width: 100%;
    height: 100%;
    z-index: 2
}

.action-widget .monaco-list {
    user-select: none;
    -webkit-user-select: none;
    border: none !important;
    border-width: 0 !important
}

.action-widget .monaco-list:focus:before {
    outline: 0 !important
}

.action-widget .monaco-list .monaco-scrollable-element {
    overflow: visible
}

.action-widget .monaco-list .monaco-list-row {
    padding: 0 10px;
    white-space: nowrap;
    cursor: pointer;
    touch-action: none;
    width: 100%
}

.action-widget .monaco-list .monaco-list-row.action.focused:not(.option-disabled) {
    background-color: var(--vscode-quickInputList-focusBackground) !important;
    color: var(--vscode-quickInputList-focusForeground);
    outline: 1px solid var(--vscode-menu-selectionBorder, transparent);
    outline-offset: -1px
}

.action-widget .monaco-list-row.group-header {
    color: var(--vscode-pickerGroup-foreground) !important;
    font-weight: 600
}

.action-widget .monaco-list .group-header,
.action-widget .monaco-list .option-disabled,
.action-widget .monaco-list .option-disabled:before,
.action-widget .monaco-list .option-disabled .focused,
.action-widget .monaco-list .option-disabled .focused:before {
    cursor: default !important;
    -webkit-touch-callout: none;
    -webkit-user-select: none;
    user-select: none;
    background-color: transparent !important;
    outline: 0 solid !important
}

.action-widget .monaco-list-row.action {
    display: flex;
    gap: 6px;
    align-items: center
}

.action-widget .monaco-list-row.action.option-disabled {
    color: var(--vscode-disabledForeground)
}

.action-widget .monaco-list-row.action.option-disabled .codicon {
    opacity: .4
}

.action-widget .monaco-list-row.action:not(.option-disabled) .codicon {
    color: inherit
}

.action-widget .monaco-list-row.action .title {
    flex: 1;
    overflow: hidden;
    text-overflow: ellipsis
}

.action-widget .action-widget-action-bar {
    background-color: var(--vscode-editorHoverWidget-statusBarBackground);
    border-top: 1px solid var(--vscode-editorHoverWidget-border)
}

.action-widget .action-widget-action-bar:before {
    display: block;
    content: "";
    width: 100%
}

.action-widget .action-widget-action-bar .actions-container {
    padding: 0 8px
}

.action-widget-action-bar .action-label {
    color: var(--vscode-textLink-activeForeground);
    font-size: 12px;
    line-height: 22px;
    padding: 0;
    pointer-events: all
}

.action-widget-action-bar .action-item {
    margin-right: 16px;
    pointer-events: none
}

.action-widget-action-bar .action-label:hover {
    background-color: transparent !important
}

.monaco-editor .codelens-decoration {
    overflow: hidden;
    display: inline-block;
    text-overflow: ellipsis;
    white-space: nowrap;
    color: var(--vscode-editorCodeLens-foreground);
    line-height: var(--vscode-editorCodeLens-lineHeight);
    font-size: var(--vscode-editorCodeLens-fontSize);
    padding-right: calc(var(--vscode-editorCodeLens-fontSize)*.5);
    font-feature-settings: var(--vscode-editorCodeLens-fontFeatureSettings);
    font-family: var(--vscode-editorCodeLens-fontFamily), var(--vscode-editorCodeLens-fontFamilyDefault)
}

.monaco-editor .codelens-decoration>span,
.monaco-editor .codelens-decoration>a {
    user-select: none;
    -webkit-user-select: none;
    white-space: nowrap;
    vertical-align: sub
}

.monaco-editor .codelens-decoration>a {
    text-decoration: none
}

.monaco-editor .codelens-decoration>a:hover {
    cursor: pointer;
    color: var(--vscode-editorLink-activeForeground) !important
}

.monaco-editor .codelens-decoration>a:hover .codicon {
    color: var(--vscode-editorLink-activeForeground) !important
}

.monaco-editor .codelens-decoration .codicon {
    vertical-align: middle;
    color: currentColor !important;
    color: var(--vscode-editorCodeLens-foreground);
    line-height: var(--vscode-editorCodeLens-lineHeight);
    font-size: var(--vscode-editorCodeLens-fontSize)
}

.monaco-editor .codelens-decoration>a:hover .codicon:before {
    cursor: pointer
}

@keyframes fadein {
    0% {
        opacity: 0;
        visibility: visible
    }

    to {
        opacity: 1
    }
}

.monaco-editor .codelens-decoration.fadein {
    animation: fadein .1s linear
}

.colorpicker-widget {
    height: 190px;
    user-select: none;
    -webkit-user-select: none
}

.colorpicker-color-decoration,
.hc-light .colorpicker-color-decoration {
    border: solid .1em #000;
    box-sizing: border-box;
    margin: .1em .2em 0;
    width: .8em;
    height: .8em;
    line-height: .8em;
    display: inline-block;
    cursor: pointer
}

.hc-black .colorpicker-color-decoration,
.vs-dark .colorpicker-color-decoration {
    border: solid .1em #eee
}

.colorpicker-header {
    display: flex;
    height: 24px;
    position: relative;
    background: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAQAAAAECAYAAACp8Z5+AAAAAXNSR0IArs4c6QAAAARnQU1BAACxjwv8YQUAAAAJcEhZcwAADsMAAA7DAcdvqGQAAAAZdEVYdFNvZnR3YXJlAHBhaW50Lm5ldCA0LjAuMTZEaa/1AAAAHUlEQVQYV2PYvXu3JAi7uLiAMaYAjAGTQBPYLQkAa/0Zef3qRswAAAAASUVORK5CYII=);
    background-size: 9px 9px;
    image-rendering: pixelated
}

.colorpicker-header .picked-color {
    width: 240px;
    display: flex;
    align-items: center;
    justify-content: center;
    line-height: 24px;
    cursor: pointer;
    color: #fff;
    flex: 1
}

.colorpicker-header .picked-color .codicon {
    color: inherit;
    font-size: 14px;
    position: absolute;
    left: 8px
}

.colorpicker-header .picked-color.light {
    color: #000
}

.colorpicker-header .original-color {
    width: 74px;
    z-index: inherit;
    cursor: pointer
}

.standalone-colorpicker {
    color: var(--vscode-editorHoverWidget-foreground);
    background-color: var(--vscode-editorHoverWidget-background);
    border: 1px solid var(--vscode-editorHoverWidget-border)
}

.colorpicker-header.standalone-colorpicker {
    border-bottom: none
}

.colorpicker-header .close-button {
    cursor: pointer;
    background-color: var(--vscode-editorHoverWidget-background);
    border-left: 1px solid var(--vscode-editorHoverWidget-border)
}

.colorpicker-header .close-button-inner-div {
    width: 100%;
    height: 100%;
    text-align: center
}

.colorpicker-header .close-button-inner-div:hover {
    background-color: var(--vscode-toolbar-hoverBackground)
}

.colorpicker-header .close-icon {
    padding: 3px
}

.colorpicker-body {
    display: flex;
    padding: 8px;
    position: relative
}

.colorpicker-body .saturation-wrap {
    overflow: hidden;
    height: 150px;
    position: relative;
    min-width: 220px;
    flex: 1
}

.colorpicker-body .saturation-box {
    height: 150px;
    position: absolute
}

.colorpicker-body .saturation-selection {
    width: 9px;
    height: 9px;
    margin: -5px 0 0 -5px;
    border: 1px solid rgb(255, 255, 255);
    border-radius: 100%;
    box-shadow: 0 0 2px #000c;
    position: absolute
}

.colorpicker-body .strip {
    width: 25px;
    height: 150px
}

.colorpicker-body .standalone-strip {
    width: 25px;
    height: 122px
}

.colorpicker-body .hue-strip {
    position: relative;
    margin-left: 8px;
    cursor: grab;
    background: linear-gradient(to bottom, #ff0000 0%, #ffff00 17%, #00ff00 33%, #00ffff 50%, #0000ff 67%, #ff00ff 83%, #ff0000 100%)
}

.colorpicker-body .opacity-strip {
    position: relative;
    margin-left: 8px;
    cursor: grab;
    background: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAQAAAAECAYAAACp8Z5+AAAAAXNSR0IArs4c6QAAAARnQU1BAACxjwv8YQUAAAAJcEhZcwAADsMAAA7DAcdvqGQAAAAZdEVYdFNvZnR3YXJlAHBhaW50Lm5ldCA0LjAuMTZEaa/1AAAAHUlEQVQYV2PYvXu3JAi7uLiAMaYAjAGTQBPYLQkAa/0Zef3qRswAAAAASUVORK5CYII=);
    background-size: 9px 9px;
    image-rendering: pixelated
}

.colorpicker-body .strip.grabbing {
    cursor: grabbing
}

.colorpicker-body .slider {
    position: absolute;
    top: 0;
    left: -2px;
    width: calc(100% + 4px);
    height: 4px;
    box-sizing: border-box;
    border: 1px solid rgba(255, 255, 255, .71);
    box-shadow: 0 0 1px #000000d9
}

.colorpicker-body .strip .overlay {
    height: 150px;
    pointer-events: none
}

.colorpicker-body .standalone-strip .standalone-overlay {
    height: 122px;
    pointer-events: none
}

.standalone-colorpicker-body {
    display: block;
    border: 1px solid transparent;
    border-bottom: 1px solid var(--vscode-editorHoverWidget-border);
    overflow: hidden
}

.colorpicker-body .insert-button {
    position: absolute;
    height: 20px;
    width: 58px;
    padding: 0;
    right: 8px;
    bottom: 8px;
    background: var(--vscode-button-background);
    color: var(--vscode-button-foreground);
    border-radius: 2px;
    border: none;
    cursor: pointer
}

.colorpicker-body .insert-button:hover {
    background: var(--vscode-button-hoverBackground)
}

.monaco-editor .goto-definition-link {
    text-decoration: underline;
    cursor: pointer;
    color: var(--vscode-editorLink-activeForeground) !important
}

.monaco-editor .peekview-widget .head {
    box-sizing: border-box;
    display: flex;
    justify-content: space-between;
    flex-wrap: nowrap
}

.monaco-editor .peekview-widget .head .peekview-title {
    display: flex;
    align-items: baseline;
    font-size: 13px;
    margin-left: 20px;
    min-width: 0;
    text-overflow: ellipsis;
    overflow: hidden
}

.monaco-editor .peekview-widget .head .peekview-title.clickable {
    cursor: pointer
}

.monaco-editor .peekview-widget .head .peekview-title .dirname:not(:empty) {
    font-size: .9em;
    margin-left: .5em
}

.monaco-editor .peekview-widget .head .peekview-title .meta {
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis
}

.monaco-editor .peekview-widget .head .peekview-title .dirname,
.monaco-editor .peekview-widget .head .peekview-title .filename {
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap
}

.monaco-editor .peekview-widget .head .peekview-title .meta:not(:empty):before {
    content: "-";
    padding: 0 .3em
}

.monaco-editor .peekview-widget .head .peekview-actions {
    flex: 1;
    text-align: right;
    padding-right: 2px
}

.monaco-editor .peekview-widget .head .peekview-actions>.monaco-action-bar {
    display: inline-block
}

.monaco-editor .peekview-widget .head .peekview-actions>.monaco-action-bar,
.monaco-editor .peekview-widget .head .peekview-actions>.monaco-action-bar>.actions-container {
    height: 100%
}

.monaco-editor .peekview-widget>.body {
    border-top: 1px solid;
    position: relative
}

.monaco-editor .peekview-widget .head .peekview-title .codicon {
    margin-right: 4px;
    align-self: center
}

.monaco-editor .peekview-widget .monaco-list .monaco-list-row.focused .codicon {
    color: inherit !important
}

.monaco-editor .zone-widget {
    position: absolute;
    z-index: 10
}

.monaco-editor .zone-widget .zone-widget-container {
    border-top-style: solid;
    border-bottom-style: solid;
    border-top-width: 0;
    border-bottom-width: 0;
    position: relative
}

.monaco-editor .zone-widget .zone-widget-container.reference-zone-widget {
    border-top-width: 1px;
    border-bottom-width: 1px
}

.monaco-editor .reference-zone-widget .inline {
    display: inline-block;
    vertical-align: top
}

.monaco-editor .reference-zone-widget .messages {
    height: 100%;
    width: 100%;
    text-align: center;
    padding: 3em 0
}

.monaco-editor .reference-zone-widget .ref-tree {
    line-height: 23px;
    background-color: var(--vscode-peekViewResult-background);
    color: var(--vscode-peekViewResult-lineForeground)
}

.monaco-editor .reference-zone-widget .ref-tree .reference {
    text-overflow: ellipsis;
    overflow: hidden
}

.monaco-editor .reference-zone-widget .ref-tree .reference-file {
    display: inline-flex;
    width: 100%;
    height: 100%;
    color: var(--vscode-peekViewResult-fileForeground)
}

.monaco-editor .reference-zone-widget .ref-tree .monaco-list:focus .selected .reference-file {
    color: inherit !important
}

.monaco-editor .reference-zone-widget .ref-tree .monaco-list:focus .monaco-list-rows>.monaco-list-row.selected:not(.highlighted) {
    background-color: var(--vscode-peekViewResult-selectionBackground);
    color: var(--vscode-peekViewResult-selectionForeground) !important
}

.monaco-editor .reference-zone-widget .ref-tree .reference-file .count {
    margin-right: 12px;
    margin-left: auto
}

.monaco-editor .reference-zone-widget .ref-tree .referenceMatch .highlight {
    background-color: var(--vscode-peekViewResult-matchHighlightBackground)
}

.monaco-editor .reference-zone-widget .preview .reference-decoration {
    background-color: var(--vscode-peekViewEditor-matchHighlightBackground);
    border: 2px solid var(--vscode-peekViewEditor-matchHighlightBorder);
    box-sizing: border-box
}

.monaco-editor .reference-zone-widget .preview .monaco-editor .monaco-editor-background,
.monaco-editor .reference-zone-widget .preview .monaco-editor .inputarea.ime-input {
    background-color: var(--vscode-peekViewEditor-background)
}

.monaco-editor .reference-zone-widget .preview .monaco-editor .margin {
    background-color: var(--vscode-peekViewEditorGutter-background)
}

.monaco-editor.hc-black .reference-zone-widget .ref-tree .reference-file,
.monaco-editor.hc-light .reference-zone-widget .ref-tree .reference-file {
    font-weight: 700
}

.monaco-editor.hc-black .reference-zone-widget .ref-tree .referenceMatch .highlight,
.monaco-editor.hc-light .reference-zone-widget .ref-tree .referenceMatch .highlight {
    border: 1px dotted var(--vscode-contrastActiveBorder, transparent);
    box-sizing: border-box
}

.monaco-hover {
    cursor: default;
    position: absolute;
    overflow: hidden;
    user-select: text;
    -webkit-user-select: text;
    box-sizing: border-box;
    animation: fadein .1s linear;
    line-height: 1.5em
}

.monaco-hover.hidden {
    display: none
}

.monaco-hover a:hover:not(.disabled) {
    cursor: pointer
}

.monaco-hover .hover-contents:not(.html-hover-contents) {
    padding: 4px 8px
}

.monaco-hover .markdown-hover>.hover-contents:not(.code-hover-contents) {
    max-width: 500px;
    word-wrap: break-word
}

.monaco-hover .markdown-hover>.hover-contents:not(.code-hover-contents) hr {
    min-width: 100%
}

.monaco-hover p,
.monaco-hover .code,
.monaco-hover ul,
.monaco-hover h1,
.monaco-hover h2,
.monaco-hover h3,
.monaco-hover h4,
.monaco-hover h5,
.monaco-hover h6 {
    margin: 8px 0
}

.monaco-hover h1,
.monaco-hover h2,
.monaco-hover h3,
.monaco-hover h4,
.monaco-hover h5,
.monaco-hover h6 {
    line-height: 1.1
}

.monaco-hover code {
    font-family: var(--monaco-monospace-font)
}

.monaco-hover hr {
    box-sizing: border-box;
    border-left: 0px;
    border-right: 0px;
    margin: 4px -8px -4px;
    height: 1px
}

.monaco-hover p:first-child,
.monaco-hover .code:first-child,
.monaco-hover ul:first-child {
    margin-top: 0
}

.monaco-hover p:last-child,
.monaco-hover .code:last-child,
.monaco-hover ul:last-child {
    margin-bottom: 0
}

.monaco-hover ul,
.monaco-hover ol {
    padding-left: 20px
}

.monaco-hover li>p {
    margin-bottom: 0
}

.monaco-hover li>ul {
    margin-top: 0
}

.monaco-hover code {
    border-radius: 3px;
    padding: 0 .4em
}

.monaco-hover .monaco-tokenized-source {
    white-space: pre-wrap
}

.monaco-hover .hover-row.status-bar {
    font-size: 12px;
    line-height: 22px
}

.monaco-hover .hover-row.status-bar .info {
    font-style: italic;
    padding: 0 8px
}

.monaco-hover .hover-row.status-bar .actions {
    display: flex;
    padding: 0 8px
}

.monaco-hover .hover-row.status-bar .actions .action-container {
    margin-right: 16px;
    cursor: pointer
}

.monaco-hover .hover-row.status-bar .actions .action-container .action .icon {
    padding-right: 4px
}

.monaco-hover .markdown-hover .hover-contents .codicon {
    color: inherit;
    font-size: inherit;
    vertical-align: middle
}

.monaco-hover .hover-contents a.code-link:hover,
.monaco-hover .hover-contents a.code-link {
    color: inherit
}

.monaco-hover .hover-contents a.code-link:before {
    content: "("
}

.monaco-hover .hover-contents a.code-link:after {
    content: ")"
}

.monaco-hover .hover-contents a.code-link>span {
    text-decoration: underline;
    border-bottom: 1px solid transparent;
    text-underline-position: under;
    color: var(--vscode-textLink-foreground)
}

.monaco-hover .hover-contents a.code-link>span:hover {
    color: var(--vscode-textLink-activeForeground)
}

.monaco-hover .markdown-hover .hover-contents:not(.code-hover-contents):not(.html-hover-contents) span {
    margin-bottom: 4px;
    display: inline-block
}

.monaco-hover-content .action-container a {
    -webkit-user-select: none;
    user-select: none
}

.monaco-hover-content .action-container.disabled {
    pointer-events: none;
    opacity: .4;
    cursor: default
}

.monaco-editor .peekview-widget .head .peekview-title .severity-icon {
    display: inline-block;
    vertical-align: text-top;
    margin-right: 4px
}

.monaco-editor .marker-widget {
    text-overflow: ellipsis;
    white-space: nowrap
}

.monaco-editor .marker-widget>.stale {
    opacity: .6;
    font-style: italic
}

.monaco-editor .marker-widget .title {
    display: inline-block;
    padding-right: 5px
}

.monaco-editor .marker-widget .descriptioncontainer {
    position: absolute;
    white-space: pre;
    user-select: text;
    -webkit-user-select: text;
    padding: 8px 12px 0 20px
}

.monaco-editor .marker-widget .descriptioncontainer .message {
    display: flex;
    flex-direction: column
}

.monaco-editor .marker-widget .descriptioncontainer .message .details {
    padding-left: 6px
}

.monaco-editor .marker-widget .descriptioncontainer .message .source,
.monaco-editor .marker-widget .descriptioncontainer .message span.code {
    opacity: .6
}

.monaco-editor .marker-widget .descriptioncontainer .message a.code-link {
    opacity: .6;
    color: inherit
}

.monaco-editor .marker-widget .descriptioncontainer .message a.code-link:before {
    content: "("
}

.monaco-editor .marker-widget .descriptioncontainer .message a.code-link:after {
    content: ")"
}

.monaco-editor .marker-widget .descriptioncontainer .message a.code-link>span {
    text-decoration: underline;
    border-bottom: 1px solid transparent;
    text-underline-position: under;
    color: var(--vscode-textLink-foreground)
}

.monaco-editor .marker-widget .descriptioncontainer .message a.code-link>span {
    color: var(--vscode-textLink-activeForeground)
}

.monaco-editor .marker-widget .descriptioncontainer .filename {
    cursor: pointer
}

.monaco-editor .zone-widget .codicon.codicon-error,
.markers-panel .marker-icon.error,
.markers-panel .marker-icon .codicon.codicon-error,
.text-search-provider-messages .providerMessage .codicon.codicon-error,
.extensions-viewlet>.extensions .codicon.codicon-error,
.extension-editor .codicon.codicon-error,
.preferences-editor .codicon.codicon-error {
    color: var(--vscode-problemsErrorIcon-foreground)
}

.monaco-editor .zone-widget .codicon.codicon-warning,
.markers-panel .marker-icon.warning,
.markers-panel .marker-icon .codicon.codicon-warning,
.text-search-provider-messages .providerMessage .codicon.codicon-warning,
.extensions-viewlet>.extensions .codicon.codicon-warning,
.extension-editor .codicon.codicon-warning,
.preferences-editor .codicon.codicon-warning {
    color: var(--vscode-problemsWarningIcon-foreground)
}

.monaco-editor .zone-widget .codicon.codicon-info,
.markers-panel .marker-icon.info,
.markers-panel .marker-icon .codicon.codicon-info,
.text-search-provider-messages .providerMessage .codicon.codicon-info,
.extensions-viewlet>.extensions .codicon.codicon-info,
.extension-editor .codicon.codicon-info,
.preferences-editor .codicon.codicon-info {
    color: var(--vscode-problemsInfoIcon-foreground)
}

.monaco-editor .inlineSuggestionsHints.withBorder {
    z-index: 39;
    color: var(--vscode-editorHoverWidget-foreground);
    background-color: var(--vscode-editorHoverWidget-background);
    border: 1px solid var(--vscode-editorHoverWidget-border)
}

.monaco-editor .inlineSuggestionsHints a,
.monaco-editor .inlineSuggestionsHints a:hover {
    color: var(--vscode-foreground)
}

.monaco-editor .inlineSuggestionsHints .keybinding {
    display: flex;
    margin-left: 4px;
    opacity: .6
}

.monaco-editor .inlineSuggestionsHints .keybinding .monaco-keybinding-key {
    font-size: 8px;
    padding: 2px 3px
}

.monaco-editor .inlineSuggestionsHints .custom-actions .action-item:nth-child(2) a {
    display: flex;
    min-width: 19px;
    justify-content: center
}

.monaco-editor .inlineSuggestionStatusBarItemLabel {
    margin-right: 2px
}

.monaco-toolbar {
    height: 100%
}

.monaco-toolbar .toolbar-toggle-more {
    display: inline-block;
    padding: 0
}

.monaco-editor .hoverHighlight {
    background-color: var(--vscode-editor-hoverHighlightBackground)
}

.monaco-editor .monaco-hover {
    color: var(--vscode-editorHoverWidget-foreground);
    background-color: var(--vscode-editorHoverWidget-background);
    border: 1px solid var(--vscode-editorHoverWidget-border);
    border-radius: 3px
}

.monaco-editor .monaco-hover a {
    color: var(--vscode-textLink-foreground)
}

.monaco-editor .monaco-hover a:hover {
    color: var(--vscode-textLink-activeForeground)
}

.monaco-editor .monaco-hover .hover-row .actions {
    background-color: var(--vscode-editorHoverWidget-statusBarBackground)
}

.monaco-editor .monaco-hover code {
    background-color: var(--vscode-textCodeBlock-background)
}

.monaco-editor.vs .dnd-target,
.monaco-editor.hc-light .dnd-target {
    border-right: 2px dotted black;
    color: #fff
}

.monaco-editor.vs-dark .dnd-target {
    border-right: 2px dotted #AEAFAD;
    color: #51504f
}

.monaco-editor.hc-black .dnd-target {
    border-right: 2px dotted #fff;
    color: #000
}

.monaco-editor.mouse-default .view-lines,
.monaco-editor.vs-dark.mac.mouse-default .view-lines,
.monaco-editor.hc-black.mac.mouse-default .view-lines,
.monaco-editor.hc-light.mac.mouse-default .view-lines {
    cursor: default
}

.monaco-editor.mouse-copy .view-lines,
.monaco-editor.vs-dark.mac.mouse-copy .view-lines,
.monaco-editor.hc-black.mac.mouse-copy .view-lines,
.monaco-editor.hc-light.mac.mouse-copy .view-lines {
    cursor: copy
}

.inline-editor-progress-decoration {
    display: inline-block;
    width: 1em;
    height: 1em
}

.inline-progress-widget {
    display: flex !important;
    justify-content: center;
    align-items: center
}

.inline-progress-widget .icon {
    font-size: 80% !important
}

.inline-progress-widget:hover .icon {
    font-size: 90% !important;
    animation: none
}

.inline-progress-widget:hover .icon:before {
    content: ""
}

.post-edit-widget {
    box-shadow: 0 0 8px 2px var(--vscode-widget-shadow);
    border: 1px solid var(--vscode-widget-border, transparent);
    border-radius: 4px;
    background-color: var(--vscode-editorWidget-background);
    overflow: hidden
}

.post-edit-widget .monaco-button {
    padding: 2px;
    border: none;
    border-radius: 0
}

.post-edit-widget .monaco-button:hover {
    background-color: var(--vscode-button-secondaryHoverBackground) !important
}

.post-edit-widget .monaco-button .codicon {
    margin: 0
}

.monaco-editor .findOptionsWidget {
    background-color: var(--vscode-editorWidget-background);
    color: var(--vscode-editorWidget-foreground);
    box-shadow: 0 0 8px 2px var(--vscode-widget-shadow);
    border: 2px solid var(--vscode-contrastBorder)
}

.monaco-editor .find-widget {
    position: absolute;
    z-index: 35;
    height: 33px;
    overflow: hidden;
    line-height: 19px;
    transition: transform .2s linear;
    padding: 0 4px;
    box-sizing: border-box;
    transform: translateY(calc(-100% - 10px));
    border-bottom-left-radius: 4px;
    border-bottom-right-radius: 4px
}

.monaco-workbench.reduce-motion .monaco-editor .find-widget {
    transition: transform 0ms linear
}

.monaco-editor .find-widget textarea {
    margin: 0
}

.monaco-editor .find-widget.hiddenEditor {
    display: none
}

.monaco-editor .find-widget.replaceToggled>.replace-part {
    display: flex
}

.monaco-editor .find-widget.visible {
    transform: translateY(0)
}

.monaco-editor .find-widget .monaco-inputbox.synthetic-focus {
    outline: 1px solid -webkit-focus-ring-color;
    outline-offset: -1px
}

.monaco-editor .find-widget .monaco-inputbox .input {
    background-color: transparent;
    min-height: 0
}

.monaco-editor .find-widget .monaco-findInput .input {
    font-size: 13px
}

.monaco-editor .find-widget>.find-part,
.monaco-editor .find-widget>.replace-part {
    margin: 3px 25px 0 17px;
    font-size: 12px;
    display: flex
}

.monaco-editor .find-widget>.find-part .monaco-inputbox,
.monaco-editor .find-widget>.replace-part .monaco-inputbox {
    min-height: 25px
}

.monaco-editor .find-widget>.replace-part .monaco-inputbox>.ibwrapper>.mirror {
    padding-right: 22px
}

.monaco-editor .find-widget>.find-part .monaco-inputbox>.ibwrapper>.input,
.monaco-editor .find-widget>.find-part .monaco-inputbox>.ibwrapper>.mirror,
.monaco-editor .find-widget>.replace-part .monaco-inputbox>.ibwrapper>.input,
.monaco-editor .find-widget>.replace-part .monaco-inputbox>.ibwrapper>.mirror {
    padding-top: 2px;
    padding-bottom: 2px
}

.monaco-editor .find-widget>.find-part .find-actions {
    height: 25px;
    display: flex;
    align-items: center
}

.monaco-editor .find-widget>.replace-part .replace-actions {
    height: 25px;
    display: flex;
    align-items: center
}

.monaco-editor .find-widget .monaco-findInput {
    vertical-align: middle;
    display: flex;
    flex: 1
}

.monaco-editor .find-widget .monaco-findInput .monaco-scrollable-element {
    width: 100%
}

.monaco-editor .find-widget .monaco-findInput .monaco-scrollable-element .scrollbar.vertical {
    opacity: 0
}

.monaco-editor .find-widget .matchesCount {
    display: flex;
    flex: initial;
    margin: 0 0 0 3px;
    padding: 2px 0 0 2px;
    height: 25px;
    vertical-align: middle;
    box-sizing: border-box;
    text-align: center;
    line-height: 23px
}

.monaco-editor .find-widget .button {
    width: 16px;
    height: 16px;
    padding: 3px;
    border-radius: 5px;
    flex: initial;
    margin-left: 3px;
    background-position: center center;
    background-repeat: no-repeat;
    cursor: pointer;
    display: flex;
    align-items: center;
    justify-content: center
}

.monaco-editor .find-widget .codicon-find-selection {
    width: 22px;
    height: 22px;
    padding: 3px;
    border-radius: 5px
}

.monaco-editor .find-widget .button.left {
    margin-left: 0;
    margin-right: 3px
}

.monaco-editor .find-widget .button.wide {
    width: auto;
    padding: 1px 6px;
    top: -1px
}

.monaco-editor .find-widget .button.toggle {
    position: absolute;
    top: 0;
    left: 3px;
    width: 18px;
    height: 100%;
    border-radius: 0;
    box-sizing: border-box
}

.monaco-editor .find-widget .button.toggle.disabled {
    display: none
}

.monaco-editor .find-widget .disabled {
    color: var(--vscode-disabledForeground);
    cursor: default
}

.monaco-editor .find-widget>.replace-part {
    display: none
}

.monaco-editor .find-widget>.replace-part>.monaco-findInput {
    position: relative;
    display: flex;
    vertical-align: middle;
    flex: auto;
    flex-grow: 0;
    flex-shrink: 0
}

.monaco-editor .find-widget>.replace-part>.monaco-findInput>.controls {
    position: absolute;
    top: 3px;
    right: 2px
}

.monaco-editor .find-widget.reduced-find-widget .matchesCount {
    display: none
}

.monaco-editor .find-widget.narrow-find-widget {
    max-width: 257px !important
}

.monaco-editor .find-widget.collapsed-find-widget {
    max-width: 170px !important
}

.monaco-editor .find-widget.collapsed-find-widget .button.previous,
.monaco-editor .find-widget.collapsed-find-widget .button.next,
.monaco-editor .find-widget.collapsed-find-widget .button.replace,
.monaco-editor .find-widget.collapsed-find-widget .button.replace-all,
.monaco-editor .find-widget.collapsed-find-widget>.find-part .monaco-findInput .controls {
    display: none
}

.monaco-editor .findMatch {
    animation-duration: 0;
    animation-name: inherit !important
}

.monaco-editor .find-widget .monaco-sash {
    left: 0 !important
}

.monaco-editor.hc-black .find-widget .button:before {
    position: relative;
    top: 1px;
    left: 2px
}

.monaco-editor .find-widget>.button.codicon-widget-close {
    position: absolute;
    top: 5px;
    right: 4px
}

.monaco-editor .margin-view-overlays .codicon-folding-manual-collapsed,
.monaco-editor .margin-view-overlays .codicon-folding-manual-expanded,
.monaco-editor .margin-view-overlays .codicon-folding-expanded,
.monaco-editor .margin-view-overlays .codicon-folding-collapsed {
    cursor: pointer;
    opacity: 0;
    transition: opacity .5s;
    display: flex;
    align-items: center;
    justify-content: center;
    font-size: 140%;
    margin-left: 2px
}

.monaco-workbench.reduce-motion .monaco-editor .margin-view-overlays .codicon-folding-manual-collapsed,
.monaco-workbench.reduce-motion .monaco-editor .margin-view-overlays .codicon-folding-manual-expanded,
.monaco-workbench.reduce-motion .monaco-editor .margin-view-overlays .codicon-folding-expanded,
.monaco-workbench.reduce-motion .monaco-editor .margin-view-overlays .codicon-folding-collapsed {
    transition: initial
}

.monaco-editor .margin-view-overlays:hover .codicon,
.monaco-editor .margin-view-overlays .codicon.codicon-folding-collapsed,
.monaco-editor .margin-view-overlays .codicon.codicon-folding-manual-collapsed,
.monaco-editor .margin-view-overlays .codicon.alwaysShowFoldIcons {
    opacity: 1
}

.monaco-editor .inline-folded:after {
    color: gray;
    margin: .1em .2em 0;
    content: "⋯";
    display: inline;
    line-height: 1em;
    cursor: pointer
}

.monaco-editor .folded-background {
    background-color: var(--vscode-editor-foldBackground)
}

.monaco-editor .cldr.codicon.codicon-folding-expanded,
.monaco-editor .cldr.codicon.codicon-folding-collapsed,
.monaco-editor .cldr.codicon.codicon-folding-manual-expanded,
.monaco-editor .cldr.codicon.codicon-folding-manual-collapsed {
    color: var(--vscode-editorGutter-foldingControlForeground) !important
}

.monaco-editor .suggest-preview-additional-widget {
    white-space: nowrap
}

.monaco-editor .suggest-preview-additional-widget .content-spacer {
    color: transparent;
    white-space: pre
}

.monaco-editor .suggest-preview-additional-widget .button {
    display: inline-block;
    cursor: pointer;
    text-decoration: underline;
    text-underline-position: under
}

.monaco-editor .ghost-text-hidden {
    opacity: 0;
    font-size: 0
}

.monaco-editor .ghost-text-decoration,
.monaco-editor .suggest-preview-text .ghost-text {
    font-style: italic
}

.monaco-editor .inline-completion-text-to-replace {
    text-decoration: underline;
    text-underline-position: under
}

.monaco-editor .ghost-text-decoration,
.monaco-editor .ghost-text-decoration-preview,
.monaco-editor .suggest-preview-text .ghost-text {
    color: var(--vscode-editorGhostText-foreground) !important;
    background-color: var(--vscode-editorGhostText-background);
    border: 1px solid var(--vscode-editorGhostText-border)
}

.monaco-editor .snippet-placeholder {
    min-width: 2px;
    outline-style: solid;
    outline-width: 1px;
    background-color: var(--vscode-editor-snippetTabstopHighlightBackground, transparent);
    outline-color: var(--vscode-editor-snippetTabstopHighlightBorder, transparent)
}

.monaco-editor .finish-snippet-placeholder {
    outline-style: solid;
    outline-width: 1px;
    background-color: var(--vscode-editor-snippetFinalTabstopHighlightBackground, transparent);
    outline-color: var(--vscode-editor-snippetFinalTabstopHighlightBorder, transparent)
}

.monaco-editor .suggest-widget {
    width: 430px;
    z-index: 40;
    display: flex;
    flex-direction: column;
    border-radius: 3px
}

.monaco-editor .suggest-widget.message {
    flex-direction: row;
    align-items: center
}

.monaco-editor .suggest-widget,
.monaco-editor .suggest-details {
    flex: 0 1 auto;
    width: 100%;
    border-style: solid;
    border-width: 1px;
    border-color: var(--vscode-editorSuggestWidget-border);
    background-color: var(--vscode-editorSuggestWidget-background)
}

.monaco-editor.hc-black .suggest-widget,
.monaco-editor.hc-black .suggest-details,
.monaco-editor.hc-light .suggest-widget,
.monaco-editor.hc-light .suggest-details {
    border-width: 2px
}

.monaco-editor .suggest-widget .suggest-status-bar {
    box-sizing: border-box;
    display: none;
    flex-flow: row nowrap;
    justify-content: space-between;
    width: 100%;
    font-size: 80%;
    padding: 0 4px;
    border-top: 1px solid var(--vscode-editorSuggestWidget-border);
    overflow: hidden
}

.monaco-editor .suggest-widget.with-status-bar .suggest-status-bar {
    display: flex
}

.monaco-editor .suggest-widget .suggest-status-bar .left {
    padding-right: 8px
}

.monaco-editor .suggest-widget.with-status-bar .suggest-status-bar .action-label {
    color: var(--vscode-editorSuggestWidgetStatus-foreground)
}

.monaco-editor .suggest-widget.with-status-bar .suggest-status-bar .action-item:not(:last-of-type) .action-label {
    margin-right: 0
}

.monaco-editor .suggest-widget.with-status-bar .suggest-status-bar .action-item:not(:last-of-type) .action-label:after {
    content: ", ";
    margin-right: .3em
}

.monaco-editor .suggest-widget.with-status-bar .monaco-list .monaco-list-row>.contents>.main>.right>.readMore,
.monaco-editor .suggest-widget.with-status-bar .monaco-list .monaco-list-row.focused.string-label>.contents>.main>.right>.readMore {
    display: none
}

.monaco-editor .suggest-widget.with-status-bar:not(.docs-side) .monaco-list .monaco-list-row:hover>.contents>.main>.right.can-expand-details>.details-label {
    width: 100%
}

.monaco-editor .suggest-widget>.message {
    padding-left: 22px
}

.monaco-editor .suggest-widget>.tree {
    height: 100%;
    width: 100%
}

.monaco-editor .suggest-widget .monaco-list {
    user-select: none;
    -webkit-user-select: none
}

.monaco-editor .suggest-widget .monaco-list .monaco-list-row {
    display: flex;
    -mox-box-sizing: border-box;
    box-sizing: border-box;
    padding-right: 10px;
    background-repeat: no-repeat;
    background-position: 2px 2px;
    white-space: nowrap;
    cursor: pointer;
    touch-action: none
}

.monaco-editor .suggest-widget .monaco-list .monaco-list-row.focused {
    color: var(--vscode-editorSuggestWidget-selectedForeground)
}

.monaco-editor .suggest-widget .monaco-list .monaco-list-row.focused .codicon {
    color: var(--vscode-editorSuggestWidget-selectedIconForeground)
}

.monaco-editor .suggest-widget .monaco-list .monaco-list-row>.contents {
    flex: 1;
    height: 100%;
    overflow: hidden;
    padding-left: 2px
}

.monaco-editor .suggest-widget .monaco-list .monaco-list-row>.contents>.main {
    display: flex;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: pre;
    justify-content: space-between
}

.monaco-editor .suggest-widget .monaco-list .monaco-list-row>.contents>.main>.left,
.monaco-editor .suggest-widget .monaco-list .monaco-list-row>.contents>.main>.right {
    display: flex
}

.monaco-editor .suggest-widget .monaco-list .monaco-list-row:not(.focused)>.contents>.main .monaco-icon-label {
    color: var(--vscode-editorSuggestWidget-foreground)
}

.monaco-editor .suggest-widget:not(.frozen) .monaco-highlighted-label .highlight {
    font-weight: 700
}

.monaco-editor .suggest-widget .monaco-list .monaco-list-row>.contents>.main .monaco-highlighted-label .highlight {
    color: var(--vscode-editorSuggestWidget-highlightForeground)
}

.monaco-editor .suggest-widget .monaco-list .monaco-list-row.focused>.contents>.main .monaco-highlighted-label .highlight {
    color: var(--vscode-editorSuggestWidget-focusHighlightForeground)
}

.monaco-editor .suggest-details>.monaco-scrollable-element>.body>.header>.codicon-close,
.monaco-editor .suggest-widget .monaco-list .monaco-list-row>.contents>.main>.right>.readMore:before {
    color: inherit;
    opacity: 1;
    font-size: 14px;
    cursor: pointer
}

.monaco-editor .suggest-details>.monaco-scrollable-element>.body>.header>.codicon-close {
    position: absolute;
    top: 6px;
    right: 2px
}

.monaco-editor .suggest-details>.monaco-scrollable-element>.body>.header>.codicon-close:hover,
.monaco-editor .suggest-widget .monaco-list .monaco-list-row>.contents>.main>.right>.readMore:hover {
    opacity: 1
}

.monaco-editor .suggest-widget .monaco-list .monaco-list-row>.contents>.main>.right>.details-label {
    opacity: .7
}

.monaco-editor .suggest-widget .monaco-list .monaco-list-row>.contents>.main>.left>.signature-label {
    overflow: hidden;
    text-overflow: ellipsis;
    opacity: .6
}

.monaco-editor .suggest-widget .monaco-list .monaco-list-row>.contents>.main>.left>.qualifier-label {
    margin-left: 12px;
    opacity: .4;
    font-size: 85%;
    line-height: initial;
    text-overflow: ellipsis;
    overflow: hidden;
    align-self: center
}

.monaco-editor .suggest-widget .monaco-list .monaco-list-row>.contents>.main>.right>.details-label {
    font-size: 85%;
    margin-left: 1.1em;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap
}

.monaco-editor .suggest-widget .monaco-list .monaco-list-row>.contents>.main>.right>.details-label>.monaco-tokenized-source {
    display: inline
}

.monaco-editor .suggest-widget .monaco-list .monaco-list-row>.contents>.main>.right>.details-label {
    display: none
}

.monaco-editor .suggest-widget:not(.shows-details) .monaco-list .monaco-list-row.focused>.contents>.main>.right>.details-label {
    display: inline
}

.monaco-editor .suggest-widget .monaco-list .monaco-list-row:not(.string-label)>.contents>.main>.right>.details-label,
.monaco-editor .suggest-widget.docs-side .monaco-list .monaco-list-row.focused:not(.string-label)>.contents>.main>.right>.details-label {
    display: inline
}

.monaco-editor .suggest-widget:not(.docs-side) .monaco-list .monaco-list-row.focused:hover>.contents>.main>.right.can-expand-details>.details-label {
    width: calc(100% - 26px)
}

.monaco-editor .suggest-widget .monaco-list .monaco-list-row>.contents>.main>.left {
    flex-shrink: 1;
    flex-grow: 1;
    overflow: hidden
}

.monaco-editor .suggest-widget .monaco-list .monaco-list-row>.contents>.main>.left>.monaco-icon-label {
    flex-shrink: 0
}

.monaco-editor .suggest-widget .monaco-list .monaco-list-row:not(.string-label)>.contents>.main>.left>.monaco-icon-label {
    max-width: 100%
}

.monaco-editor .suggest-widget .monaco-list .monaco-list-row.string-label>.contents>.main>.left>.monaco-icon-label {
    flex-shrink: 1
}

.monaco-editor .suggest-widget .monaco-list .monaco-list-row>.contents>.main>.right {
    overflow: hidden;
    flex-shrink: 4;
    max-width: 70%
}

.monaco-editor .suggest-widget .monaco-list .monaco-list-row>.contents>.main>.right>.readMore {
    display: inline-block;
    position: absolute;
    right: 10px;
    width: 18px;
    height: 18px;
    visibility: hidden
}

.monaco-editor .suggest-widget.docs-side .monaco-list .monaco-list-row>.contents>.main>.right>.readMore {
    display: none !important
}

.monaco-editor .suggest-widget .monaco-list .monaco-list-row.string-label>.contents>.main>.right>.readMore {
    display: none
}

.monaco-editor .suggest-widget .monaco-list .monaco-list-row.focused.string-label>.contents>.main>.right>.readMore {
    display: inline-block
}

.monaco-editor .suggest-widget .monaco-list .monaco-list-row.focused:hover>.contents>.main>.right>.readMore {
    visibility: visible
}

.monaco-editor .suggest-widget .monaco-list .monaco-list-row .monaco-icon-label.deprecated {
    opacity: .66;
    text-decoration: unset
}

.monaco-editor .suggest-widget .monaco-list .monaco-list-row .monaco-icon-label.deprecated>.monaco-icon-label-container>.monaco-icon-name-container {
    text-decoration: line-through
}

.monaco-editor .suggest-widget .monaco-list .monaco-list-row .monaco-icon-label:before {
    height: 100%
}

.monaco-editor .suggest-widget .monaco-list .monaco-list-row .icon {
    display: block;
    height: 16px;
    width: 16px;
    margin-left: 2px;
    background-repeat: no-repeat;
    background-size: 80%;
    background-position: center
}

.monaco-editor .suggest-widget .monaco-list .monaco-list-row .icon.hide {
    display: none
}

.monaco-editor .suggest-widget .monaco-list .monaco-list-row .suggest-icon {
    display: flex;
    align-items: center;
    margin-right: 4px
}

.monaco-editor .suggest-widget.no-icons .monaco-list .monaco-list-row .icon,
.monaco-editor .suggest-widget.no-icons .monaco-list .monaco-list-row .suggest-icon:before {
    display: none
}

.monaco-editor .suggest-widget .monaco-list .monaco-list-row .icon.customcolor .colorspan {
    margin: 0 0 0 .3em;
    border: .1em solid #000;
    width: .7em;
    height: .7em;
    display: inline-block
}

.monaco-editor .suggest-details-container {
    z-index: 41
}

.monaco-editor .suggest-details {
    display: flex;
    flex-direction: column;
    cursor: default;
    color: var(--vscode-editorSuggestWidget-foreground)
}

.monaco-editor .suggest-details.focused {
    border-color: var(--vscode-focusBorder)
}

.monaco-editor .suggest-details a {
    color: var(--vscode-textLink-foreground)
}

.monaco-editor .suggest-details a:hover {
    color: var(--vscode-textLink-activeForeground)
}

.monaco-editor .suggest-details code {
    background-color: var(--vscode-textCodeBlock-background)
}

.monaco-editor .suggest-details.no-docs {
    display: none
}

.monaco-editor .suggest-details>.monaco-scrollable-element {
    flex: 1
}

.monaco-editor .suggest-details>.monaco-scrollable-element>.body {
    box-sizing: border-box;
    height: 100%;
    width: 100%
}

.monaco-editor .suggest-details>.monaco-scrollable-element>.body>.header>.type {
    flex: 2;
    overflow: hidden;
    text-overflow: ellipsis;
    opacity: .7;
    white-space: pre;
    margin: 0 24px 0 0;
    padding: 4px 0 12px 5px
}

.monaco-editor .suggest-details>.monaco-scrollable-element>.body>.header>.type.auto-wrap {
    white-space: normal;
    word-break: break-all
}

.monaco-editor .suggest-details>.monaco-scrollable-element>.body>.docs {
    margin: 0;
    padding: 4px 5px;
    white-space: pre-wrap
}

.monaco-editor .suggest-details.no-type>.monaco-scrollable-element>.body>.docs {
    margin-right: 24px;
    overflow: hidden
}

.monaco-editor .suggest-details>.monaco-scrollable-element>.body>.docs.markdown-docs {
    padding: 0;
    white-space: initial;
    min-height: calc(1rem + 8px)
}

.monaco-editor .suggest-details>.monaco-scrollable-element>.body>.docs.markdown-docs>div,
.monaco-editor .suggest-details>.monaco-scrollable-element>.body>.docs.markdown-docs>span:not(:empty) {
    padding: 4px 5px
}

.monaco-editor .suggest-details>.monaco-scrollable-element>.body>.docs.markdown-docs>div>p:first-child {
    margin-top: 0
}

.monaco-editor .suggest-details>.monaco-scrollable-element>.body>.docs.markdown-docs>div>p:last-child {
    margin-bottom: 0
}

.monaco-editor .suggest-details>.monaco-scrollable-element>.body>.docs.markdown-docs .monaco-tokenized-source {
    white-space: pre
}

.monaco-editor .suggest-details>.monaco-scrollable-element>.body>.docs .code {
    white-space: pre-wrap;
    word-wrap: break-word
}

.monaco-editor .suggest-details>.monaco-scrollable-element>.body>.docs.markdown-docs .codicon {
    vertical-align: sub
}

.monaco-editor .suggest-details>.monaco-scrollable-element>.body>p:empty {
    display: none
}

.monaco-editor .suggest-details code {
    border-radius: 3px;
    padding: 0 .4em
}

.monaco-editor .suggest-details ul,
.monaco-editor .suggest-details ol {
    padding-left: 20px
}

.monaco-editor .suggest-details p code {
    font-family: var(--monaco-monospace-font)
}

.monaco-editor.vs .valueSetReplacement {
    outline: solid 2px var(--vscode-editorBracketMatch-border)
}

.monaco-editor .linked-editing-decoration {
    background-color: var(--vscode-editor-linkedEditingBackground);
    min-width: 1px
}

.monaco-editor .detected-link,
.monaco-editor .detected-link-active {
    text-decoration: underline;
    text-underline-position: under
}

.monaco-editor .detected-link-active {
    cursor: pointer;
    color: var(--vscode-editorLink-activeForeground) !important
}

.monaco-editor .focused .selectionHighlight {
    background-color: var(--vscode-editor-selectionHighlightBackground);
    box-sizing: border-box;
    border: 1px solid var(--vscode-editor-selectionHighlightBorder)
}

.monaco-editor.hc-black .focused .selectionHighlight,
.monaco-editor.hc-light .focused .selectionHighlight {
    border-style: dotted
}

.monaco-editor .wordHighlight {
    background-color: var(--vscode-editor-wordHighlightBackground);
    box-sizing: border-box;
    border: 1px solid var(--vscode-editor-wordHighlightBorder)
}

.monaco-editor.hc-black .wordHighlight,
.monaco-editor.hc-light .wordHighlight {
    border-style: dotted
}

.monaco-editor .wordHighlightStrong {
    background-color: var(--vscode-editor-wordHighlightStrongBackground);
    box-sizing: border-box;
    border: 1px solid var(--vscode-editor-wordHighlightStrongBorder)
}

.monaco-editor.hc-black .wordHighlightStrong,
.monaco-editor.hc-light .wordHighlightStrong {
    border-style: dotted
}

.monaco-editor .wordHighlightText {
    background-color: var(--vscode-editor-wordHighlightTextBackground);
    box-sizing: border-box;
    border: 1px solid var(--vscode-editor-wordHighlightTextBorder)
}

.monaco-editor.hc-black .wordHighlightText,
.monaco-editor.hc-light .wordHighlightText {
    border-style: dotted
}

.monaco-editor .parameter-hints-widget {
    z-index: 39;
    display: flex;
    flex-direction: column;
    line-height: 1.5em;
    cursor: default;
    color: var(--vscode-editorHoverWidget-foreground);
    background-color: var(--vscode-editorHoverWidget-background);
    border: 1px solid var(--vscode-editorHoverWidget-border)
}

.hc-black .monaco-editor .parameter-hints-widget,
.hc-light .monaco-editor .parameter-hints-widget {
    border-width: 2px
}

.monaco-editor .parameter-hints-widget>.phwrapper {
    max-width: 440px;
    display: flex;
    flex-direction: row
}

.monaco-editor .parameter-hints-widget.multiple {
    min-height: 3.3em;
    padding: 0
}

.monaco-editor .parameter-hints-widget.multiple .body:before {
    content: "";
    display: block;
    height: 100%;
    position: absolute;
    opacity: .5;
    border-left: 1px solid var(--vscode-editorHoverWidget-border)
}

.monaco-editor .parameter-hints-widget p,
.monaco-editor .parameter-hints-widget ul {
    margin: 8px 0
}

.monaco-editor .parameter-hints-widget .monaco-scrollable-element,
.monaco-editor .parameter-hints-widget .body {
    display: flex;
    flex: 1;
    flex-direction: column;
    min-height: 100%
}

.monaco-editor .parameter-hints-widget .signature {
    padding: 4px 5px;
    position: relative
}

.monaco-editor .parameter-hints-widget .signature.has-docs:after {
    content: "";
    display: block;
    position: absolute;
    left: 0;
    width: 100%;
    padding-top: 4px;
    opacity: .5;
    border-bottom: 1px solid var(--vscode-editorHoverWidget-border)
}

.monaco-editor .parameter-hints-widget .docs {
    padding: 0 10px 0 5px;
    white-space: pre-wrap
}

.monaco-editor .parameter-hints-widget .docs.empty {
    display: none
}

.monaco-editor .parameter-hints-widget .docs a {
    color: var(--vscode-textLink-foreground)
}

.monaco-editor .parameter-hints-widget .docs a:hover {
    color: var(--vscode-textLink-activeForeground);
    cursor: pointer
}

.monaco-editor .parameter-hints-widget .docs .markdown-docs {
    white-space: initial
}

.monaco-editor .parameter-hints-widget .docs code {
    font-family: var(--monaco-monospace-font);
    border-radius: 3px;
    padding: 0 .4em;
    background-color: var(--vscode-textCodeBlock-background)
}

.monaco-editor .parameter-hints-widget .docs .monaco-tokenized-source,
.monaco-editor .parameter-hints-widget .docs .code {
    white-space: pre-wrap
}

.monaco-editor .parameter-hints-widget .controls {
    display: none;
    flex-direction: column;
    align-items: center;
    min-width: 22px;
    justify-content: flex-end
}

.monaco-editor .parameter-hints-widget.multiple .controls {
    display: flex;
    padding: 0 2px
}

.monaco-editor .parameter-hints-widget.multiple .button {
    width: 16px;
    height: 16px;
    background-repeat: no-repeat;
    cursor: pointer
}

.monaco-editor .parameter-hints-widget .button.previous {
    bottom: 24px
}

.monaco-editor .parameter-hints-widget .overloads {
    text-align: center;
    height: 12px;
    line-height: 12px;
    font-family: var(--monaco-monospace-font)
}

.monaco-editor .parameter-hints-widget .signature .parameter.active {
    color: var(--vscode-editorHoverWidget-highlightForeground);
    font-weight: 700
}

.monaco-editor .parameter-hints-widget .documentation-parameter>.parameter {
    font-weight: 700;
    margin-right: .5em
}

.monaco-editor .rename-box {
    z-index: 100;
    color: inherit;
    border-radius: 4px
}

.monaco-editor .rename-box.preview {
    padding: 4px 4px 0
}

.monaco-editor .rename-box .rename-input {
    padding: 3px;
    border-radius: 2px
}

.monaco-editor .rename-box .rename-label {
    display: none;
    opacity: .8
}

.monaco-editor .rename-box.preview .rename-label {
    display: inherit
}

.monaco-editor .sticky-line {
    color: var(--vscode-editorLineNumber-foreground);
    overflow: hidden;
    white-space: nowrap;
    display: inline-block
}

.monaco-editor .sticky-line-number {
    text-align: right;
    float: left
}

.monaco-editor .sticky-line-root {
    background-color: inherit;
    overflow: hidden;
    white-space: nowrap;
    width: 100%
}

.monaco-editor.hc-black .sticky-widget,
.monaco-editor.hc-light .sticky-widget {
    border-bottom: 1px solid var(--vscode-contrastBorder)
}

.monaco-editor .sticky-line-root:hover {
    background-color: var(--vscode-editorStickyScrollHover-background);
    cursor: pointer
}

.monaco-editor .sticky-widget {
    width: 100%;
    box-shadow: var(--vscode-scrollbar-shadow) 0 3px 2px -2px;
    z-index: 4;
    background-color: var(--vscode-editorStickyScroll-background)
}

.monaco-editor .sticky-widget.peek {
    background-color: var(--vscode-peekViewEditorStickyScroll-background)
}

.monaco-editor .unicode-highlight {
    border: 1px solid var(--vscode-editorUnicodeHighlight-border);
    background-color: var(--vscode-editorUnicodeHighlight-background);
    box-sizing: border-box
}

.editor-banner {
    box-sizing: border-box;
    cursor: default;
    width: 100%;
    font-size: 12px;
    display: flex;
    overflow: visible;
    height: 26px;
    background: var(--vscode-banner-background)
}

.editor-banner .icon-container {
    display: flex;
    flex-shrink: 0;
    align-items: center;
    padding: 0 6px 0 10px
}

.editor-banner .icon-container.custom-icon {
    background-repeat: no-repeat;
    background-position: center center;
    background-size: 16px;
    width: 16px;
    padding: 0;
    margin: 0 6px 0 10px
}

.editor-banner .message-container {
    display: flex;
    align-items: center;
    line-height: 26px;
    text-overflow: ellipsis;
    white-space: nowrap;
    overflow: hidden
}

.editor-banner .message-container p {
    margin-block-start: 0;
    margin-block-end: 0
}

.editor-banner .message-actions-container {
    flex-grow: 1;
    flex-shrink: 0;
    line-height: 26px;
    margin: 0 4px
}

.editor-banner .message-actions-container a.monaco-button {
    width: inherit;
    margin: 2px 8px;
    padding: 0 12px
}

.editor-banner .message-actions-container a {
    padding: 3px;
    margin-left: 12px;
    text-decoration: underline
}

.editor-banner .action-container {
    padding: 0 10px 0 6px
}

.editor-banner {
    background-color: var(--vscode-banner-background)
}

.editor-banner,
.editor-banner .action-container .codicon,
.editor-banner .message-actions-container .monaco-link {
    color: var(--vscode-banner-foreground)
}

.editor-banner .icon-container .codicon {
    color: var(--vscode-banner-iconForeground)
}

.monaco-link {
    color: var(--vscode-textLink-foreground)
}

.monaco-link:hover {
    color: var(--vscode-textLink-activeForeground)
}

.monaco-editor .iPadShowKeyboard {
    width: 58px;
    min-width: 0;
    height: 36px;
    min-height: 0;
    margin: 0;
    padding: 0;
    position: absolute;
    resize: none;
    overflow: hidden;
    background: url(data:image/svg+xml;base64,PHN2ZyB3aWR0aD0iNTMiIGhlaWdodD0iMzYiIHZpZXdCb3g9IjAgMCA1MyAzNiIgZmlsbD0ibm9uZSIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KPGcgY2xpcC1wYXRoPSJ1cmwoI2NsaXAwKSI+CjxwYXRoIGZpbGwtcnVsZT0iZXZlbm9kZCIgY2xpcC1ydWxlPSJldmVub2RkIiBkPSJNNDguMDM2NCA0LjAxMDQySDQuMDA3NzlMNC4wMDc3OSAzMi4wMjg2SDQ4LjAzNjRWNC4wMTA0MlpNNC4wMDc3OSAwLjAwNzgxMjVDMS43OTcyMSAwLjAwNzgxMjUgMC4wMDUxODc5OSAxLjc5OTg0IDAuMDA1MTg3OTkgNC4wMTA0MlYzMi4wMjg2QzAuMDA1MTg3OTkgMzQuMjM5MiAxLjc5NzIxIDM2LjAzMTIgNC4wMDc3OSAzNi4wMzEySDQ4LjAzNjRDNTAuMjQ3IDM2LjAzMTIgNTIuMDM5IDM0LjIzOTIgNTIuMDM5IDMyLjAyODZWNC4wMTA0MkM1Mi4wMzkgMS43OTk4NCA1MC4yNDcgMC4wMDc4MTI1IDQ4LjAzNjQgMC4wMDc4MTI1SDQuMDA3NzlaTTguMDEwNDIgOC4wMTMwMkgxMi4wMTNWMTIuMDE1Nkg4LjAxMDQyVjguMDEzMDJaTTIwLjAxODIgOC4wMTMwMkgxNi4wMTU2VjEyLjAxNTZIMjAuMDE4MlY4LjAxMzAyWk0yNC4wMjA4IDguMDEzMDJIMjguMDIzNFYxMi4wMTU2SDI0LjAyMDhWOC4wMTMwMlpNMzYuMDI4NiA4LjAxMzAySDMyLjAyNlYxMi4wMTU2SDM2LjAyODZWOC4wMTMwMlpNNDAuMDMxMiA4LjAxMzAySDQ0LjAzMzlWMTIuMDE1Nkg0MC4wMzEyVjguMDEzMDJaTTE2LjAxNTYgMTYuMDE4Mkg4LjAxMDQyVjIwLjAyMDhIMTYuMDE1NlYxNi4wMTgyWk0yMC4wMTgyIDE2LjAxODJIMjQuMDIwOFYyMC4wMjA4SDIwLjAxODJWMTYuMDE4MlpNMzIuMDI2IDE2LjAxODJIMjguMDIzNFYyMC4wMjA4SDMyLjAyNlYxNi4wMTgyWk00NC4wMzM5IDE2LjAxODJWMjAuMDIwOEgzNi4wMjg2VjE2LjAxODJINDQuMDMzOVpNMTIuMDEzIDI0LjAyMzRIOC4wMTA0MlYyOC4wMjZIMTIuMDEzVjI0LjAyMzRaTTE2LjAxNTYgMjQuMDIzNEgzNi4wMjg2VjI4LjAyNkgxNi4wMTU2VjI0LjAyMzRaTTQ0LjAzMzkgMjQuMDIzNEg0MC4wMzEyVjI4LjAyNkg0NC4wMzM5VjI0LjAyMzRaIiBmaWxsPSIjNDI0MjQyIi8+CjwvZz4KPGRlZnM+CjxjbGlwUGF0aCBpZD0iY2xpcDAiPgo8cmVjdCB3aWR0aD0iNTMiIGhlaWdodD0iMzYiIGZpbGw9IndoaXRlIi8+CjwvY2xpcFBhdGg+CjwvZGVmcz4KPC9zdmc+Cg==) center center no-repeat;
    border: 4px solid #F6F6F6;
    border-radius: 4px
}

.monaco-editor.vs-dark .iPadShowKeyboard {
    background: url(data:image/svg+xml;base64,PHN2ZyB3aWR0aD0iNTMiIGhlaWdodD0iMzYiIHZpZXdCb3g9IjAgMCA1MyAzNiIgZmlsbD0ibm9uZSIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KPGcgY2xpcC1wYXRoPSJ1cmwoI2NsaXAwKSI+CjxwYXRoIGZpbGwtcnVsZT0iZXZlbm9kZCIgY2xpcC1ydWxlPSJldmVub2RkIiBkPSJNNDguMDM2NCA0LjAxMDQySDQuMDA3NzlMNC4wMDc3OSAzMi4wMjg2SDQ4LjAzNjRWNC4wMTA0MlpNNC4wMDc3OSAwLjAwNzgxMjVDMS43OTcyMSAwLjAwNzgxMjUgMC4wMDUxODc5OSAxLjc5OTg0IDAuMDA1MTg3OTkgNC4wMTA0MlYzMi4wMjg2QzAuMDA1MTg3OTkgMzQuMjM5MiAxLjc5NzIxIDM2LjAzMTIgNC4wMDc3OSAzNi4wMzEySDQ4LjAzNjRDNTAuMjQ3IDM2LjAzMTIgNTIuMDM5IDM0LjIzOTIgNTIuMDM5IDMyLjAyODZWNC4wMTA0MkM1Mi4wMzkgMS43OTk4NCA1MC4yNDcgMC4wMDc4MTI1IDQ4LjAzNjQgMC4wMDc4MTI1SDQuMDA3NzlaTTguMDEwNDIgOC4wMTMwMkgxMi4wMTNWMTIuMDE1Nkg4LjAxMDQyVjguMDEzMDJaTTIwLjAxODIgOC4wMTMwMkgxNi4wMTU2VjEyLjAxNTZIMjAuMDE4MlY4LjAxMzAyWk0yNC4wMjA4IDguMDEzMDJIMjguMDIzNFYxMi4wMTU2SDI0LjAyMDhWOC4wMTMwMlpNMzYuMDI4NiA4LjAxMzAySDMyLjAyNlYxMi4wMTU2SDM2LjAyODZWOC4wMTMwMlpNNDAuMDMxMiA4LjAxMzAySDQ0LjAzMzlWMTIuMDE1Nkg0MC4wMzEyVjguMDEzMDJaTTE2LjAxNTYgMTYuMDE4Mkg4LjAxMDQyVjIwLjAyMDhIMTYuMDE1NlYxNi4wMTgyWk0yMC4wMTgyIDE2LjAxODJIMjQuMDIwOFYyMC4wMjA4SDIwLjAxODJWMTYuMDE4MlpNMzIuMDI2IDE2LjAxODJIMjguMDIzNFYyMC4wMjA4SDMyLjAyNlYxNi4wMTgyWk00NC4wMzM5IDE2LjAxODJWMjAuMDIwOEgzNi4wMjg2VjE2LjAxODJINDQuMDMzOVpNMTIuMDEzIDI0LjAyMzRIOC4wMTA0MlYyOC4wMjZIMTIuMDEzVjI0LjAyMzRaTTE2LjAxNTYgMjQuMDIzNEgzNi4wMjg2VjI4LjAyNkgxNi4wMTU2VjI0LjAyMzRaTTQ0LjAzMzkgMjQuMDIzNEg0MC4wMzEyVjI4LjAyNkg0NC4wMzM5VjI0LjAyMzRaIiBmaWxsPSIjQzVDNUM1Ii8+CjwvZz4KPGRlZnM+CjxjbGlwUGF0aCBpZD0iY2xpcDAiPgo8cmVjdCB3aWR0aD0iNTMiIGhlaWdodD0iMzYiIGZpbGw9IndoaXRlIi8+CjwvY2xpcFBhdGg+CjwvZGVmcz4KPC9zdmc+Cg==) center center no-repeat;
    border: 4px solid #252526
}

.monaco-editor .tokens-inspect-widget {
    z-index: 50;
    user-select: text;
    -webkit-user-select: text;
    padding: 10px;
    color: var(--vscode-editorHoverWidget-foreground);
    background-color: var(--vscode-editorHoverWidget-background);
    border: 1px solid var(--vscode-editorHoverWidget-border)
}

.monaco-editor.hc-black .tokens-inspect-widget,
.monaco-editor.hc-light .tokens-inspect-widget {
    border-width: 2px
}

.monaco-editor .tokens-inspect-widget .tokens-inspect-separator {
    height: 1px;
    border: 0;
    background-color: var(--vscode-editorHoverWidget-border)
}

.monaco-editor .tokens-inspect-widget .tm-token {
    font-family: var(--monaco-monospace-font)
}

.monaco-editor .tokens-inspect-widget .tm-token-length {
    font-weight: 400;
    font-size: 60%;
    float: right
}

.monaco-editor .tokens-inspect-widget .tm-metadata-table {
    width: 100%
}

.monaco-editor .tokens-inspect-widget .tm-metadata-value {
    font-family: var(--monaco-monospace-font);
    text-align: right
}

.monaco-editor .tokens-inspect-widget .tm-token-type {
    font-family: var(--monaco-monospace-font)
}

@keyframes _1e4c7pz1 {
    0% {
        transform: rotate(0)
    }

    to {
        transform: rotate(360deg)
    }
}

._1e4c7pz0 {
    width: 100%;
    height: 100%;
    display: flex;
    align-items: center;
    justify-content: center;
    padding: 0
}

._1e4c7pz3 {
    height: 12px;
    width: 12px
}

._1e4c7pz4 {
    height: 16px;
    width: 16px
}

._1e4c7pz5 {
    height: 24px;
    width: 24px
}

._1e4c7pz6 {
    height: 36px;
    width: 36px
}

._1e4c7pz7 {
    transform-origin: center;
    animation: _1e4c7pz1 1s cubic-bezier(.4, 0, .2, 1) infinite;
    fill: var(--ColorNeutral12)
}

._1e4c7pz8 {
    animation-duration: 1.25s
}

._1e4c7pz9 {
    animation-duration: .75s
}

._1e4c7pza {
    animation-duration: .5s
}

._1e4c7pzb {
    fill: var(--ColorNeutral12)
}

._1a0j2an0 {
    display: flex;
    flex-direction: column;
    gap: 6px;
    width: 100%
}

._1a0j2an1 {
    width: auto;
    white-space: nowrap;
    color: var(--ColorNeutral12);
    font-size: 12px;
    line-height: 1
}

._1a0j2an2 {
    position: absolute;
    top: -9999px !important;
    left: -9999px !important
}

._1a0j2an3 {
    all: unset;
    box-sizing: border-box;
    width: 100%;
    height: 32px;
    padding-left: 8px;
    border-radius: 2px;
    font-family: var(--FontsMono);
    font-size: 12px;
    line-height: 1;
    color: var(--ColorNeutral11);
    background-color: var(--ColorNeutral3);
    border: 1px solid var(--ColorNeutral4)
}

._1a0j2an3:focus {
    color: var(--ColorNeutral12);
    background-color: var(--ColorNeutral5);
    border: 1px solid var(--ColorNeutral6)
}

._1a0j2an3::placeholder {
    color: var(--ColorNeutral8)
}

._1a0j2an4 {
    width: 100%;
    position: relative;
    cursor: pointer;
    color: var(--ColorYellow10);
    border-top: 1px solid var(--ColorNeutral4);
    border-right: 1px solid var(--ColorNeutral4);
    border-bottom: 1px solid var(--ColorNeutral4)
}

._1a0j2an4:focus {
    background-color: var(--ColorNeutral2)
}

._1a0j2an5 {
    all: unset;
    box-sizing: border-box;
    display: flex;
    align-items: center;
    width: 100%;
    height: 28px;
    color: var(--ColorYellow10)
}

._1a0j2an6 {
    position: absolute;
    right: 12px;
    top: 9px;
    height: 10px;
    width: 10px
}

._1a0j2an7 {
    display: flex;
    flex-direction: column;
    gap: 24px
}

._1a0j2an8 {
    display: grid;
    grid-template-columns: 160px 1fr;
    gap: 24px
}

._1a0j2an9 {
    display: flex;
    flex-direction: column;
    align-items: center;
    color: var(--ColorNeutral8)
}

._1a0j2ana {
    display: flex;
    align-items: center;
    color: var(--ColorNeutral12)
}

._1pdhcrt0 {
    display: flex;
    transform: rotate(0)
}

._1pdhcrt1 {
    transform: rotate(90deg)
}

._1pdhcrt2 {
    transform: rotate(180deg)
}

._1pdhcrt3 {
    transform: rotate(270deg)
}

._1pdhcrt4 {
    height: var(--Space12);
    width: var(--Space12)
}

._1pdhcrt5 {
    height: var(--Space16);
    width: var(--Space16)
}

._1pdhcrt6 {
    height: var(--Space20);
    width: var(--Space20)
}

._1pdhcrt0 svg path {
    fill: var(--ColorNeutral11);
    transition: all .15s cubic-bezier(.4, 0, .2, 1)
}

.mmxpni0 {
    margin: 0;
    line-height: 1.5;
    font-weight: 400;
    font-size: 11px;
    font-family: var(--FontsMono)
}

.mmxpni1 {
    color: var(--ColorNeutral10)
}

.mmxpni2 {
    color: var(--ColorRed10)
}

._12y82qv1 {
    padding: 12px;
    margin-bottom: 12px;
    width: 100%;
    font-family: var(--FontsMono);
    font-size: 11px;
    background-color: var(--ColorNeutral11);
    color: var(--ColorNeutral2);
    font-weight: 500;
    border-radius: 2px;
    transition: all .1s cubic-bezier(.4, 0, .2, 1)
}

._12y82qv1:hover {
    background-color: var(--ColorNeutral12);
    color: var(--ColorNeutral1)
}

.r669ku0 {
    user-select: none;
    display: flex;
    align-items: center;
    gap: var(--Space2);
    border-radius: var(--Space2);
    font-size: 13px;
    font-weight: 400;
    transition: all 75ms cubic-bezier(.4, 0, .2, 1);
    color: var(--ColorNeutral11)
}

.r669ku0:hover {
    color: var(--ColorNeutral12)
}

.r669ku1 {
    cursor: not-allowed;
    opacity: .35;
    background-color: var(--ColorNeutral3);
    border: 1px solid var(--ColorNeutral3)
}

.r669ku2 {
    background-color: var(--ColorNeutral1)
}

.r669ku2:hover {
    background-color: var(--ColorNeutral4)
}

.r669ku3 {
    background-color: var(--ColorNeutral2)
}

.r669ku3:hover {
    background-color: var(--ColorNeutral5)
}

.r669ku4 {
    background-color: var(--ColorNeutral3)
}

.r669ku4:hover {
    background-color: var(--ColorNeutral6)
}

.r669ku5 {
    height: var(--Space24)
}

.r669ku6 {
    height: var(--Space28)
}

.r669ku7 {
    height: 40px
}

.r669ku8 {
    width: 100%
}

.r669ku9 {
    width: fit-content
}

.r669kue {
    border: 1px solid var(--ColorNeutral6)
}

.r669kuf {
    border: 1px solid var(--ColorNeutral7)
}

.r669kug {
    border: 1px solid var(--ColorNeutral8)
}

.r669kuh {
    padding-right: var(--Space8);
    padding-left: var(--Space4)
}

.r669kui {
    padding-right: var(--Space8);
    padding-left: var(--Space8)
}

.r669kuj {
    padding-right: var(--Space8);
    padding-left: var(--Space4)
}

.r669kuk {
    padding-right: var(--Space8);
    padding-left: var(--Space8)
}

.r669kul {
    padding-right: var(--Space12);
    padding-left: var(--Space8)
}

.r669kum {
    padding-right: var(--Space12);
    padding-left: var(--Space12)
}

.odecjn0 {
    position: fixed;
    z-index: 2;
    height: 100%;
    width: 100%;
    display: flex;
    flex-direction: column;
    align-items: center;
    justify-content: center;
    transition: all .35s cubic-bezier(.4, 0, .2, 1)
}

.odecjn1 {
    opacity: 1;
    visibility: visible
}

.odecjn2 {
    opacity: 0;
    visibility: hidden
}

.odecjn3 {
    padding: 0 0 16px;
    margin: 0
}

.odecjn4 {
    height: 100%;
    width: 100%;
    display: flex;
    flex-direction: column;
    align-items: center;
    justify-content: center;
    position: relative
}

.odecjn5 {
    position: relative;
    z-index: 2;
    color: var(--ColorNeutral12);
    width: 100%;
    display: flex;
    flex-direction: column;
    gap: 16px;
    font-size: 14px;
    transition: all .35s cubic-bezier(.4, 0, .2, 1)
}

.odecjn6 {
    opacity: 1;
    visibility: visible
}

.odecjn7 {
    opacity: 0;
    visibility: hidden
}

.odecjn8 {
    display: flex;
    flex-direction: column;
    gap: 16px;
    transition: all .15s ease-in-out;
    overflow-y: auto
}

.odecjn9 {
    max-height: 220px
}

.odecjna {
    max-height: 0;
    margin-bottom: -16px
}

.odecjnb {
    display: grid;
    grid-template-columns: 180px 1fr;
    gap: 12px
}

.odecjnb:nth-of-type(1) {
    margin-top: 8px
}

.odecjnc {
    height: 32px;
    width: fit-content;
    color: var(--ColorNeutral11)
}

.odecjnc:hover {
    color: var(--ColorNeutral12)
}

.odecjnd {
    display: flex;
    justify-content: space-between;
    width: 100%;
    border-top: 1px solid var(--ColorNeutralAlpha4);
    padding-top: 16px
}

.odecjne {
    display: flex;
    line-height: 1.3;
    margin-left: -8px;
    margin-bottom: 8px;
    align-content: center;
    color: var(--ColorNeutral11)
}

.odecjne:hover {
    color: var(--ColorNeutral12)
}

.odecjnf {
    color: var(--ColorNeutral11);
    text-decoration: underline
}

.odecjng {
    height: 32px;
    display: flex;
    align-items: center;
    gap: 8px;
    padding: 0 var(--Space12);
    border: 1px solid var(--ColorNeutral12);
    color: var(--ColorNeutral12);
    border-radius: 4px;
    transition: all .15s cubic-bezier(.4, 0, .2, 1)
}

.odecjng:hover {
    background-color: var(--ColorNeutral12);
    color: var(--ColorNeutral1)
}

.odecjng:disabled {
    cursor: not-allowed;
    opacity: .5
}

.odecjng:disabled.odecjng:hover {
    background-color: transparent;
    color: var(--ColorNeutral12)
}

.odecjnh {
    display: flex;
    width: 100%;
    justify-content: flex-end;
    padding-top: 12px
}

.odecjni {
    border-radius: 4px;
    padding: 12px;
    margin-top: 12px;
    background-color: var(--ColorNeutral2)
}

.odecjnl {
    border: 1px dotted var(--ColorNeutral11)
}

.odecjnm {
    border: 1px solid var(--ColorRed10)
}

.odecjnn {
    position: absolute;
    width: 45%;
    height: 40%;
    z-index: 1;
    top: 50%;
    left: 65%;
    filter: blur(100px);
    border-radius: 50%;
    transform: translateZ(0) translate(-50%, -50%);
    background-color: var(--ColorBlue9)
}

.odecjno {
    position: absolute;
    width: 45%;
    height: 40%;
    z-index: 1;
    top: 50%;
    left: 35%;
    filter: blur(100px);
    border-radius: 50%;
    transform: translateZ(0) translate(-50%, -50%);
    background-color: var(--ColorPurple9)
}

._8yr53d0 {
    display: flex;
    align-items: center;
    justify-content: center;
    flex-shrink: 0;
    border-radius: var(--Space4);
    transition: all .05s cubic-bezier(.4, 0, .2, 1)
}

._8yr53d1 {
    background-color: var(--ColorNeutral6)
}

._8yr53d3 {
    cursor: not-allowed;
    opacity: .65
}

._8yr53d4:hover {
    background-color: var(--ColorNeutral3)
}

._8yr53d5:hover {
    background-color: var(--ColorNeutral5)
}

._8yr53d6:hover {
    background-color: var(--ColorNeutral6)
}

._8yr53d7 {
    height: var(--Space20);
    width: var(--Space20)
}

._8yr53d8 {
    height: var(--Space24);
    width: var(--Space24)
}

._8yr53d9 {
    height: var(--Space28);
    width: var(--Space28)
}

._8yr53da {
    background-color: var(--ColorNeutral4);
    border: 1px solid var(--ColorNeutral6)
}

._8yr53db {
    background-color: var(--ColorNeutral5);
    border: 1px solid var(--ColorNeutral7)
}

._8yr53dc {
    background-color: var(--ColorNeutral6);
    border: 1px solid var(--ColorNeutral8)
}

._8r15860 {
    height: 100%;
    width: 100%;
    display: flex;
    flex: 1;
    min-width: 0;
    transition: opacity .15s ease
}

._8r15861 {
    opacity: 1;
    visibility: visible
}

._8r15862 {
    opacity: 0;
    visibility: hidden
}

.inactive-definition {
    opacity: .25
}

._55klhk0 {
    box-sizing: border-box;
    display: inline-flex;
    align-items: center;
    justify-content: center;
    height: var(--Space20);
    min-width: var(--Space20);
    padding: 0 var(--Space4);
    background-color: var(--ColorNeutral1);
    color: var(--ColorNeutral10);
    border-radius: var(--Space4);
    border: 1px solid var(--ColorNeutral6);
    font-size: 12px
}

.vdtnvh0 {
    width: 100%;
    height: 100%;
    display: flex;
    flex-direction: column;
    justify-content: flex-end;
    position: relative
}

.vdtnvh1 {
    transition: opacity .1s cubic-bezier(.4, 0, .2, 1)
}

.vdtnvh2 {
    visibility: hidden;
    opacity: 0;
    height: 0;
    padding: 0
}

.vdtnvh3 {
    visibility: visible;
    opacity: 1;
    overflow-y: auto;
    height: 100%;
    position: relative;
    padding-top: var(--Space12);
    padding-right: var(--Space12);
    padding-bottom: var(--Space12)
}

.vdtnvh4 {
    opacity: .25 !important
}

.vdtnvh5 {
    opacity: 1 !important
}

.vdtnvh6 {
    height: 100%;
    width: 100%;
    display: flex;
    align-items: center;
    justify-content: center;
    gap: var(--Space16);
    color: var(--ColorNeutral6);
    font-size: 14px;
    cursor: default
}

@keyframes _1po4jx82 {
    to {
        opacity: 1
    }

    0% {
        opacity: 0
    }
}

._1po4jx80 {
    display: flex;
    justify-content: right
}

._1po4jx81 {
    position: relative
}

._1po4jx83 {
    display: flex;
    flex-direction: column;
    gap: 8px;
    border: 1px solid var(--ColorNeutral5);
    border-radius: var(--Space4);
    background-color: var(--ColorNeutral3);
    padding: var(--Space8);
    width: 220px;
    position: absolute;
    top: 28px;
    right: 0;
    z-index: 1;
    animation: _1po4jx82 .15s cubic-bezier(.4, 0, .2, 1)
}

._1po4jx84 {
    top: 24px
}

._1po4jx85 {
    top: 32px
}

._1po4jx86 {
    top: 36px
}

.bg6rqa0 {
    display: flex;
    align-items: center;
    justify-content: center;
    height: var(--Space16);
    padding-right: 4px;
    padding-left: 4px;
    width: fit-content;
    border-radius: 2px;
    font-family: var(--FontsMono);
    font-size: 9px;
    text-transform: uppercase;
    white-space: nowrap
}

.bg6rqa1 {
    color: var(--ColorNeutral12);
    border: 1px solid var(--ColorNeutral5);
    background-color: var(--ColorNeutral2)
}

.bg6rqa2 {
    color: var(--ColorRed12);
    border: 1px solid var(--ColorRed5);
    background-color: var(--ColorRed2)
}

.bg6rqa3 {
    color: var(--ColorOrange12);
    border: 1px solid var(--ColorOrange5);
    background-color: var(--ColorOrange2)
}

.bg6rqa4 {
    color: var(--ColorYellow12);
    border: 1px solid var(--ColorYellow5);
    background-color: var(--ColorYellow2)
}

.bg6rqa5 {
    color: var(--ColorGreen12);
    border: 1px solid var(--ColorGreen5);
    background-color: var(--ColorGreen2)
}

.bg6rqa6 {
    color: var(--ColorBlue12);
    border: 1px solid var(--ColorBlue5);
    background-color: var(--ColorBlue2)
}

.bg6rqa7 {
    color: var(--ColorPurple12);
    border: 1px solid var(--ColorPurple5);
    background-color: var(--ColorPurple2)
}

._1vl8nmd0 {
    width: 100%;
    height: 40px;
    display: flex;
    align-items: center;
    flex-shrink: 0;
    background-color: var(--ColorNeutral2);
    overflow-x: auto
}

._1vl8nmd1 {
    height: inherit;
    display: flex;
    align-items: center;
    gap: 8px;
    padding-left: 3px;
    padding-right: 3px
}

._1vl8nmd2 {
    padding-right: var(--Space8)
}

._1vl8nmd3 {
    flex-shrink: 0;
    height: 100%;
    position: relative;
    display: flex;
    align-items: center;
    flex-wrap: nowrap;
    min-width: 0;
    padding-left: 8px;
    padding-right: 8px;
    font-size: 14px;
    transition: opacity .15s cubic-bezier(.4, 0, .2, 1)
}

._1vl8nmd3:hover {
    color: var(--ColorNeutral12);
    opacity: 1
}

._1vl8nmd4 {
    opacity: .65;
    color: var(--ColorNeutral10)
}

._1vl8nmd5 {
    opacity: 1;
    color: var(--ColorNeutral12);
    background-color: var(--ColorNeutral1)
}

._1vl8nmd5:after {
    content: "";
    position: absolute;
    bottom: 0;
    left: 0;
    height: 2px;
    width: 100%;
    background-color: var(--ColorGreen10)
}

._1vl8nmd6 {
    margin-left: var(--Space8);
    margin-right: var(--Space8)
}

._2t03830 {
    height: 48px;
    display: flex;
    flex-shrink: 0;
    justify-content: space-between;
    align-items: center
}

._2t03831 {
    display: flex;
    font-size: 14px;
    color: var(--ColorNeutral11)
}

._2t03832 {
    display: flex
}

._2t03833 {
    display: flex;
    gap: var(--Space8);
    align-items: center
}

.nfjr1u0 {
    width: 100%;
    background-color: var(--ColorOrange4);
    color: var(--ColorOrange11);
    border: 1px solid var(--ColorOrange6);
    padding: var(--Space12);
    display: flex;
    flex-direction: column;
    gap: var(--Space8);
    font-size: 12px;
    margin-top: var(--Space12);
    border-radius: var(--Space4)
}

.nfjr1u0 span {
    font-size: 10px;
    color: var(--ColorOrange11);
    display: block;
    text-transform: uppercase;
    line-height: 1
}

.nfjr1u0 p {
    color: var(--ColorOrange12);
    padding: 0;
    margin: 0
}

.gumgn70 {
    width: 100%;
    height: 100%;
    display: flex;
    flex-direction: column;
    justify-content: flex-end;
    position: relative;
    padding-right: var(--Space12);
    padding-left: var(--Space12)
}

.gumgn71 {
    overflow-y: auto;
    height: 100%;
    position: relative;
    padding-top: var(--Space12);
    padding-bottom: var(--Space12);
    padding-left: var(--Space12)
}

.gumgn72 {
    display: block;
    padding-left: var(--Space4);
    padding-right: var(--Space4)
}

.gumgn72:after {
    content: "";
    display: block;
    margin-top: 2px;
    height: 20px;
    width: 1px;
    background-color: var(--ColorNeutral3)
}

._1gmdo3h0 {
    display: grid;
    height: 100%;
    width: 100%;
    position: relative;
    overflow: hidden
}

._1gmdo3h1 {
    opacity: 1;
    visibility: visible
}

._1gmdo3h2 {
    opacity: 0;
    visibility: hidden
}

._1gmdo3h3 {
    overflow: hidden
}

._1gmdo3h4 {
    position: relative;
    z-index: 2;
    background-color: transparent
}

._1gmdo3h4:after {
    content: "";
    position: absolute;
    z-index: 1;
    left: 50%;
    top: 50%;
    transform: translate3d(-50%, -50%, 0);
    border-radius: 8px;
    transition: background-color .15s ease;
    background-color: transparent
}

._1gmdo3h4:hover:after {
    background-color: var(--ColorNeutral6)
}

._1gmdo3h5 {
    width: 100%;
    height: 12px;
    top: -6px;
    cursor: row-resize
}

._1gmdo3h5:after {
    height: 4px;
    width: 110px
}

._1gmdo3h6 {
    height: 100%;
    width: 12px;
    left: -6px;
    cursor: col-resize
}

._1gmdo3h6:after {
    width: 4px;
    height: 110px
}

._1owkyej0 {
    all: unset;
    box-sizing: border-box;
    display: grid;
    grid-template-columns: 12px max(120px) 1fr 1fr 32px;
    grid-template-rows: 36px;
    gap: 8px;
    align-items: center;
    justify-content: space-between;
    width: 100%;
    padding-left: var(--Space16);
    font-size: 12px;
    font-weight: 400;
    color: var(--ColorNeutral10);
    cursor: pointer
}

._1owkyej0:last-of-type {
    border-bottom: none
}

._1owkyej0:nth-of-type(odd) {
    background-color: var(--ColorNeutralAlpha2)
}

._1owkyej0:hover {
    color: var(--ColorNeutral12)
}

._1owkyej1 {
    background-color: var(--ColorNeutral3);
    color: var(--ColorNeutral12);
    font-weight: 500;
    position: relative
}

._1owkyej1:after {
    content: "";
    position: absolute;
    right: 1px;
    top: 0;
    height: 100%;
    width: 2px;
    background-color: var(--ColorGreen10)
}

._1owkyej3 {
    display: flex;
    align-items: center;
    justify-items: center
}

._1owkyej4 {
    gap: 8px
}

._1owkyej5 {
    gap: 12px
}

._1owkyej6 {
    gap: 24px
}

._1owkyej7 {
    display: block;
    white-space: nowrap;
    font-family: var(--FontsMono);
    font-size: 10px
}

._1owkyej8 {
    height: 100%;
    width: 6px;
    display: flex;
    align-items: center;
    justify-items: center
}

._1owkyej9 {
    display: block;
    height: 6px;
    width: 6px;
    border-radius: 50%
}

._1owkyeja {
    background-color: var(--ColorBlue10)
}

._1owkyejb {
    background-color: var(--ColorGreen10)
}

._1owkyejc {
    background-color: var(--ColorYellow10)
}

._1owkyejd {
    background-color: var(--ColorOrange10)
}

._1owkyeje,
._1owkyejf {
    background-color: var(--ColorRed10)
}

._1f7ov3f0 {
    padding: var(--Space12)
}

._1f7ov3f1 {
    display: flex;
    gap: 2px;
    align-items: center;
    height: 24px;
    width: 100%;
    font-family: var(--FontsMono);
    font-weight: 500;
    font-size: 10px;
    text-transform: uppercase;
    color: var(--ColorNeutral12)
}

._1f7ov3f2 {
    padding: var(--Space4) var(--Space16) var(--Space16)
}

._3u9wl20 {
    padding: var(--Space12)
}

._1ril8vl0 {
    display: flex;
    flex-shrink: 0;
    position: relative;
    padding-left: 8px
}

._1ril8vl1 {
    height: 32px
}

._1ril8vl2 {
    height: 40px
}

._1ril8vl3 {
    width: auto;
    position: relative;
    padding-bottom: 2px;
    padding-left: var(--Space12);
    padding-right: var(--Space12);
    text-align: center;
    font-size: 14px;
    color: var(--ColorNeutral9)
}

._1ril8vl3:hover {
    color: var(--ColorNeutral12)
}

._1ril8vl3:after {
    content: "";
    position: absolute;
    width: calc(100% - var(--Space24));
    height: 2px;
    bottom: 1px;
    left: var(--Space12);
    z-index: 1
}

._1ril8vl3[data-headlessui-state=selected] {
    color: var(--ColorNeutral12)
}

._1ril8vl3[data-headlessui-state=selected]._1ril8vl3:after {
    background-color: var(--ColorGreen10)
}

._1ril8vl4 {
    width: 100%;
    height: 100%;
    display: flex;
    flex-direction: column
}

._1ril8vl5 {
    color: var(--ColorNeutral7);
    position: relative;
    height: 100%
}

._1ril8vl6 {
    height: 100%;
    overflow-y: auto;
    overflow-x: hidden
}

._1mb6xtq0 {
    display: flex;
    flex-direction: column;
    height: 100%;
    width: 100%;
    color: var(--ColorNeutral5)
}

._1mb6xtq1 {
    display: flex;
    flex-direction: column;
    height: 100%;
    width: 100%
}

._1mb6xtq2 {
    all: unset;
    overflow-x: hidden;
    overflow-y: auto;
    height: 100%;
    margin: 0;
    padding: 0;
    display: flex;
    flex-direction: column
}

._1mb6xtq3 {
    display: flex;
    flex-shrink: 0;
    align-items: center;
    justify-content: space-between;
    height: 32px;
    padding: 0 var(--Space16);
    font-size: 12px;
    color: var(--ColorNeutral12)
}

._1mb6xtq4 {
    padding-top: 24px;
    padding-bottom: 12px;
    font-size: 12px;
    width: 100%;
    text-align: center;
    color: var(--ColorNeutral9)
}

.gnzr3d0 {
    display: flex;
    align-items: center;
    transition: opacity .1s ease
}

.gnzr3d1 {
    opacity: .35
}

.gnzr3d3 {
    width: 0;
    height: 0;
    visibility: hidden;
    margin: 0
}

.gnzr3d4 {
    display: flex;
    align-items: center;
    justify-content: space-between;
    cursor: pointer;
    position: relative;
    transition: background-color .2s
}

.gnzr3d5 {
    background: var(--ColorGreen10)
}

.gnzr3d6 {
    background: var(--ColorNeutral6)
}

.gnzr3d7 {
    cursor: not-allowed
}

.gnzr3d9 {
    width: 64px;
    height: 32px;
    border-radius: 32px
}

.gnzr3da {
    width: 48px;
    height: 24px;
    border-radius: 24px
}

.gnzr3db {
    width: 38px;
    height: 18px;
    border-radius: 18px
}

.gnzr3dc {
    display: block;
    position: absolute;
    top: 2px;
    left: 2px;
    background: var(--ColorNeutral2);
    box-shadow: 0 0 2px 0 var(--ColorNeutral4);
    transition: all .15s
}

.gnzr3dd {
    background: var(--ColorNeutral11)
}

.gnzr3de {
    background: var(--ColorNeutral12);
    left: calc(100% - 2px) !important;
    transform: translate(-100%) !important
}

.gnzr3df {
    width: 28px;
    height: 28px;
    border-radius: 14px
}

.gnzr3dg {
    width: 20px;
    height: 20px;
    border-radius: 10px
}

.gnzr3dh {
    width: 14px;
    height: 14px;
    top: 2px;
    left: 2px;
    border-radius: 7px
}

._1dtrtkk0 {
    display: flex;
    flex-direction: column;
    gap: var(--Space12);
    padding-top: 20px;
    padding-left: 16px;
    padding-right: 16px
}

._1dtrtkk2 {
    margin-top: 16px
}

._1dtrtkk3 {
    margin-top: 0
}

._1dtrtkk4 {
    display: grid;
    align-items: center;
    justify-content: center;
    gap: var(--Space12);
    grid-template-columns: 48px .4fr .6fr var(--Space24)
}

._1dtrtkk5 {
    display: flex;
    flex-direction: column;
    gap: var(--Space12)
}

._1dtrtkk7 {
    margin-top: 16px
}

._1dtrtkk9 {
    width: fit-content;
    color: var(--ColorNeutral12);
    font-size: 12px;
    margin-top: var(--Space12);
    text-decoration: underline
}

._1ugjige0 {
    display: flex;
    flex-direction: column;
    width: 100%;
    height: 100%;
    padding: var(--Space12)
}

._1ugjige1 {
    padding-top: var(--Space16);
    padding-right: var(--Space16);
    height: 100%
}

.ncc2oq0 {
    display: flex;
    flex-direction: column;
    height: 100%;
    width: 100%;
    position: relative;
    background-color: var(--ColorNeutral2)
}

._1ms2x770 {
    color: var(--ColorYellow10);
    cursor: default
}

.fasm370 {
    color: var(--ColorNeutral10)
}

.fasm371 {
    padding-left: 2px
}

.fasm372 {
    padding-right: 2px
}

.fasm373 {
    padding-left: 2px;
    padding-right: 2px
}

.du9sae0 {
    display: flex;
    flex-direction: column;
    padding-top: 4px;
    padding-bottom: 4px;
    color: var(--ColorNeutral12)
}

.du9sae0>:first-child {
    margin-top: 0
}

.du9sae0>:last-child {
    margin-bottom: 0
}

.du9sae0 blockquote {
    margin-left: 0;
    margin-right: 0;
    padding-left: 8px;
    border-left: 2px solid var(--ColorNeutral7)
}

.du9sae0 code {
    border-radius: 2px;
    background-color: var(--ColorNeutral4);
    padding: 2px
}

.du9sae0 pre {
    overflow: auto;
    padding: 8px;
    border-radius: 4px;
    background-color: var(--ColorNeutral4);
    font-size: 14px;
    line-height: 1.5;
    color: var(--ColorNeutral12);
    margin-top: 0;
    margin-bottom: 12px
}

.du9sae0 ol {
    list-style-type: decimal;
    padding-left: 16px;
    font-size: 14px;
    line-height: 1.5;
    color: var(--ColorNeutral12);
    margin-top: 0;
    margin-bottom: 12px
}

.du9sae0 p,
.du9sae0 blockquote,
.du9sae0 dl,
.du9sae0 table {
    font-size: 14px;
    line-height: 1.5;
    color: var(--ColorNeutral12);
    margin-top: 0;
    margin-bottom: 12px
}

.du9sae0 details {
    font-size: 14px;
    line-height: 1.5;
    color: var(--ColorNeutral12);
    margin-top: 0;
    margin-bottom: 12px
}

.du9sae0 ul {
    list-style-type: disc;
    padding-left: 16px;
    font-size: 14px;
    line-height: 1.5;
    color: var(--ColorNeutral12);
    margin-top: 0;
    margin-bottom: 12px
}

.du9sae0 a {
    color: var(--ColorBlue12)
}

.du9sae0 hr {
    all: unset;
    border-top: 1px solid var(--ColorNeutral8)
}

.du9sae0 img {
    max-height: 120px;
    max-width: 100px
}

._1oua3fw0 {
    display: flex;
    flex-direction: column;
    gap: 10px;
    padding: 8px 0 8px 12px
}

._1oua3fw2 {
    border-left: 1px solid var(--ColorNeutral4);
    margin-left: -12px;
    padding-left: 12px
}

._1oua3fw3 {
    display: flex;
    flex-direction: column
}

._1oua3fw4 {
    color: var(--ColorOrange11)
}

._9axphw0 {
    padding: 24px;
    height: 100%;
    overflow-y: auto
}

._9axphw1 {
    color: var(--ColorBlue11)
}

._9axphw1:hover {
    text-decoration: underline
}

._9axphw2 {
    color: var(--ColorRed11)
}

._9axphw3 {
    padding: 12px;
    color: var(--ColorOrange12);
    border-radius: 2px;
    border: 1px solid var(--ColorOrange5);
    background-color: var(--ColorOrange1)
}

._9axphw4 {
    color: var(--ColorBlue11)
}

._9axphw4:hover {
    text-decoration: underline
}

._9axphw5 {
    color: var(--ColorBlue11)
}

._9axphw6 {
    color: var(--ColorGreen11)
}

._9axphw7 {
    color: var(--ColorPurple11)
}

.fenb1w0 {
    border-left: 1px solid var(--ColorNeutral4);
    margin: 12px 0;
    padding-left: 8px
}

.fenb1w1 {
    display: flex;
    flex-direction: column;
    border-left: var(--ColorNeutral6);
    margin: 8px 0
}

._1vouuk60 {
    display: flex;
    flex-direction: column;
    margin-bottom: 24px;
    color: var(--ColorNeutral12)
}

._1vouuk61 {
    display: flex;
    text-transform: uppercase;
    line-height: 1;
    font-size: 10px;
    letter-spacing: .5px;
    margin-bottom: 12px;
    color: var(--ColorNeutral11)
}

._1vouuk62 {
    color: var(--ColorGreen10);
    margin-bottom: 8px
}

._1eqdtpt1 {
    flex-grow: 0
}

.wc46l0 {
    color: var(--ColorYellow10);
    margin-bottom: 8px
}

._1joovsj0 {
    height: 100%;
    width: 100%;
    display: flex;
    flex-direction: column;
    gap: 16px;
    padding-top: 24px;
    overflow: auto
}

._1joovsj1:nth-of-type(1) {
    text-transform: uppercase;
    line-height: 1;
    font-size: 10px;
    letter-spacing: .5px;
    color: var(--ColorNeutral9);
    white-space: nowrap
}

._1joovsj1:nth-of-type(2) {
    color: var(--ColorNeutral12);
    font-weight: 500;
    max-width: 100%;
    overflow: hidden;
    white-space: nowrap;
    text-overflow: ellipsis
}

._1joovsj2 {
    width: 100%;
    display: flex;
    flex-direction: column;
    align-items: flex-start;
    gap: 12px;
    padding-top: 2px
}

._1joovsj3 {
    display: flex;
    align-items: center;
    padding-bottom: 12px
}

._1joovsj4 {
    display: flex;
    flex-direction: column;
    flex-grow: 1;
    height: 100%;
    overflow: hidden;
    padding-top: 24px;
    font-size: 14px
}

._1joovsj5 {
    transform: rotate(90deg);
    flex-shrink: 0
}

._10hldco0 {
    position: relative;
    display: flex;
    align-items: center;
    gap: 12px;
    width: calc(100% + 48px);
    margin-left: -24px;
    height: 40px;
    padding-left: 24px;
    padding-right: 24px;
    color: var(--ColorNeutral11)
}

._10hldco0:hover {
    color: var(--ColorNeutral12);
    background-color: var(--ColorNeutralAlpha2)
}

._10hldco0:after {
    content: "";
    position: absolute;
    width: 2px;
    height: 100%;
    top: 0;
    right: 0;
    background-color: transparent
}

._10hldco1,
._10hldco1:hover {
    background-color: var(--ColorNeutralAlpha3);
    color: var(--ColorNeutral12)
}

._10hldco1:after {
    background-color: var(--ColorGreen10)
}

._1wdf7y10 {
    color: var(--ColorNeutral10);
    height: 100%;
    width: 100%;
    position: relative;
    display: flex;
    flex-direction: column;
    overflow: hidden;
    font-size: 14px
}

._1wdf7y11 {
    display: flex;
    align-items: center;
    flex-grow: 0;
    flex-shrink: 0;
    color: var(--ColorNeutral11);
    padding-left: 24px;
    padding-right: 24px;
    height: 40px;
    width: 100%
}

._1wdf7y12 {
    display: flex;
    padding-left: 8px;
    padding-right: 8px
}

._1wdf7y13 {
    display: flex;
    gap: 2px
}

._1wdf7y14 {
    height: 100%;
    display: flex;
    overflow: hidden
}

.barpax0 {
    transition: all .35s cubic-bezier(.4, 0, .2, 1)
}

.barpax1 {
    visibility: visible;
    opacity: 1
}

.barpax2 {
    visibility: hidden;
    opacity: 0
}

.barpax3 {
    display: flex;
    gap: 2px;
    align-content: center
}

.hl1jvn0 {
    white-space: nowrap;
    height: 22px;
    font-size: 14px;
    display: flex;
    align-items: center;
    transition: all .1s cubic-bezier(.4, 0, .2, 1)
}

.hl1jvn0:hover {
    color: var(--ColorNeutral12)
}

.hl1jvn0:disabled {
    cursor: not-allowed;
    color: var(--ColorNeutral6)
}

.hl1jvn0:disabled.hl1jvn0:hover {
    color: var(--ColorNeutral6)
}

.hl1jvn2 {
    padding-right: 4px;
    padding-left: 4px;
    border-radius: 4px
}

.hl1jvn5 {
    font-weight: 600;
    color: var(--ColorNeutral12)
}

.hl1jvn5:hover {
    color: var(--ColorNeutral12)
}

.hl1jvn6 {
    color: var(--ColorNeutral11)
}

.hl1jvn7 {
    display: flex;
    align-items: center;
    gap: var(--Space4);
    width: 100%
}

.hl1jvn9 {
    color: var(--ColorOrange7)
}

.hl1jvna {
    color: var(--ColorOrange5)
}

._17bn0oi0 {
    display: flex;
    position: relative;
    padding-left: 16px
}

._17bn0oi0:before {
    content: "";
    position: absolute;
    top: 10px;
    left: 2px;
    height: 1px;
    width: 6px;
    background-color: var(--ColorNeutral4)
}

._16kitfy0 {
    background-color: var(--ColorNeutral3);
    border: 1px solid var(--ColorNeutral5);
    padding-bottom: var(--Space12);
    border-radius: var(--Space4);
    position: absolute;
    top: var(--Space12);
    left: var(--Space12);
    overflow-y: auto;
    height: calc(100% - var(--Space24));
    width: calc(100% - var(--Space24));
    transition: all .15s cubic-bezier(.4, 0, .2, 1)
}

._16kitfy1 {
    visibility: visible;
    opacity: 1;
    transform: scale(1)
}

._16kitfy2 {
    visibility: hidden;
    opacity: 0;
    transform: scale(.96)
}

._16kitfy3,
._16kitfy4 {
    position: relative;
    height: 100%;
    width: 100%
}

._16kitfy5 {
    position: absolute;
    top: 0;
    left: 0;
    height: 100%;
    width: 100%
}

._1arqqhj0 {
    position: relative;
    margin-left: 4px
}

._1arqqhj1 {
    margin-bottom: var(--Space8)
}

._1arqqhj3 {
    height: 24px;
    width: 100%;
    display: flex;
    align-items: center;
    gap: var(--Space4);
    font-size: 11px;
    color: var(--ColorNeutral10)
}

._1arqqhj3:hover {
    color: var(--ColorNeutral12)
}

._1arqqhj4 {
    width: 100%;
    margin-left: var(--Space4);
    position: relative
}

._1arqqhj4:after {
    content: "";
    position: absolute;
    top: -4px;
    left: 1px;
    height: calc(100% - 5px);
    width: 1px;
    border-left: 1px solid var(--ColorNeutral4)
}

._1arqqhj5 {
    all: unset;
    margin: 0;
    overflow: hidden;
    display: flex;
    flex-direction: column;
    position: relative
}

.gkjdkj0 {
    height: var(--Space20);
    width: var(--Space20);
    transform-origin: center
}

.gkjdkj1 {
    transform: rotate(0)
}

.gkjdkj2 {
    transform: rotate(-90deg)
}

.in8g5b0 {
    height: var(--Space20);
    width: var(--Space20);
    display: flex;
    justify-content: center;
    align-items: center
}

._7amv3d0 {
    all: unset;
    width: 100%;
    position: relative
}

._7amv3d1:before {
    content: "";
    position: absolute;
    top: 10px;
    left: -10px;
    height: 1px;
    width: 12px;
    background-color: var(--ColorNeutral4)
}

._7amv3d1:last-of-type._7amv3d1:after {
    content: "";
    position: absolute;
    z-index: 1;
    top: 11px;
    left: -11px;
    height: 100%;
    width: 1px;
    background-color: var(--ColorNeutral1)
}

._7amv3d5 {
    width: 100%;
    display: flex;
    align-items: center;
    gap: 2px
}

._7amv3d6 {
    display: flex;
    width: 100%
}

._7amv3d7 {
    display: grid;
    grid-template-columns: var(--Space20) 1fr
}

._7amv3d8 {
    position: relative;
    padding-left: var(--Space16);
    margin-top: var(--Space4);
    margin-left: var(--Space4)
}

._7amv3d8:after {
    content: "";
    position: absolute;
    top: -6px;
    left: 5px;
    height: calc(100% - 3px);
    width: 1px;
    background-color: var(--ColorNeutral4)
}

._7amv3d9 {
    margin-bottom: 8px
}

._7amv3da {
    display: none
}

._7amv3db {
    all: unset;
    padding: 0;
    margin: 0;
    display: flex;
    flex-direction: column;
    gap: 2px
}

._1ge0wmv0 {
    height: 100%;
    width: 100%;
    padding: var(--Space16);
    margin: 0;
    display: flex;
    flex-direction: column;
    gap: 2px
}

.d4edtl0 {
    position: relative;
    height: 100%;
    width: 100%;
    box-sizing: border-box;
    overflow: hidden
}

._17t867s0 {
    display: flex;
    justify-content: center;
    padding-top: 8px;
    padding-bottom: 8px
}

._17t867s1 {
    position: fixed;
    z-index: 4;
    background-color: var(--ColorNeutral2);
    border: 1px solid var(--ColorNeutral4);
    padding: 24px;
    border-radius: 8px;
    top: 50%;
    left: 50%;
    transform: translate3d(-50%, -50%, 0);
    max-width: 50%;
    width: 100%
}

._17t867s2 {
    position: fixed;
    z-index: 3;
    background-color: var(--ColorNeutralAlpha1);
    top: 0;
    left: 0;
    height: 100%;
    width: 100%;
    -webkit-backdrop-filter: blur(3px);
    backdrop-filter: blur(3px)
}

._17t867s3 {
    cursor: default;
    display: flex;
    align-content: center;
    align-items: center;
    gap: 12px;
    border-radius: 9px;
    font-size: 14px;
    justify-content: center;
    width: 40%;
    background-color: var(--ColorNeutral2);
    color: var(--ColorNeutral10)
}

._17t867s4 {
    height: 100%;
    width: 32px;
    display: flex;
    justify-content: center;
    align-items: center
}

._3fwqnq0 {
    box-sizing: border-box;
    height: 100%;
    width: 100%;
    padding: 12px
}

._3fwqnq1 {
    height: 100%;
    width: 100%;
    border: 1px solid var(--ColorNeutral4);
    padding-top: 12px;
    padding-bottom: 12px
}

._609q6x0 {
    height: 100%;
    width: 100%;
    display: flex;
    background-color: var(--ColorNeutral1);
    font-family: var(--FontsBody);
    color: var(--ColorNeutral12)
}

._609q6x1 {
    height: 100%;
    width: 100%;
    display: flex;
    flex-direction: column
}

._1bm9zjn0 {
    display: grid;
    height: 100%;
    overflow: hidden
}

._1bm9zjn2 {
    grid-template-rows: 48px 1fr
}

._1bm9zjn3 {
    display: grid;
    grid-template-columns: 60px 1fr;
    height: 100%;
    overflow: hidden
}

._1bm9zjn4 {
    display: flex;
    flex-direction: column;
    align-items: center;
    justify-content: space-between;
    padding-bottom: 12px
}

._1bm9zjn5 {
    display: flex;
    flex-direction: column;
    align-items: center;
    color: var(--ColorNeutral12);
    overflow: hidden;
    gap: 12px;
    padding-top: 12px;
    padding-bottom: 12px
}

._1bm9zjn6 {
    height: 40px;
    width: 40px;
    display: flex;
    align-items: center;
    justify-content: center;
    border: 1px solid var(--ColorNeutral7);
    background-color: var(--ColorNeutral4);
    border-radius: 4px;
    transition: all .15s cubic-bezier(.4, 0, .2, 1)
}

._1bm9zjn6:hover,
._1bm9zjn7 {
    opacity: 1
}

._1bm9zjn8 {
    opacity: .35
}

._1bm9zjn9 {
    height: 100%;
    width: 100%;
    overflow: hidden
}

._1bm9zjnb {
    visibility: visible;
    opacity: 1;
    height: 100%;
    width: 100%
}

._1bm9zjnc {
    visibility: hidden;
    opacity: 0;
    height: 0;
    width: 0
}

._194xw0o0 {
    height: 100%;
    width: 100%;
    background-color: var(--ColorNeutral1)
}

._194xw0o1 {
    height: 100%;
    width: 100%;
    background-color: var(--ColorNeutral1);
    padding-left: 25%;
    padding-right: 25%;
    display: flex;
    align-content: center;
    justify-content: center
}